"""
Python module generated from Java source file org.bukkit.event.entity.EntityCombustEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Entity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityCombustEvent(EntityEvent, Cancellable):
    """
    Called when an entity combusts.
    
    If an Entity Combust event is cancelled, the entity will not combust.
    """

    def __init__(self, combustee: "Entity", duration: int):
        ...


    def __init__(self, combustee: "Entity", duration: float):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getDuration(self) -> float:
        """
        Returns
        - the amount of time (in seconds) the combustee should be alight
            for
        """
        ...


    def setDuration(self, duration: float) -> None:
        """
        The number of seconds the combustee should be alight for.
        
        This value will only ever increase the combustion time, not decrease
        existing combustion times.

        Arguments
        - duration: the time in seconds to be alight for.
        """
        ...


    def setDuration(self, duration: int) -> None:
        """
        The number of seconds the combustee should be alight for.
        
        This value will only ever increase the combustion time, not decrease
        existing combustion times.

        Arguments
        - duration: the time in seconds to be alight for.

        See
        - .setDuration(float)

        Deprecated
        - duration is now a float
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.primitives.Bytes

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.primitives import *
from java.io import Serializable
from java.util import AbstractList
from java.util import Arrays
from java.util import Collections
from java.util import RandomAccess
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class Bytes:

    @staticmethod
    def hashCode(value: int) -> int:
        """
        Returns a hash code for `value`; equal to the result of invoking `((Byte)
        value).hashCode()`.
        
        **Java 8+ users:** use Byte.hashCode(byte) instead.

        Arguments
        - value: a primitive `byte` value

        Returns
        - a hash code for the value
        """
        ...


    @staticmethod
    def contains(array: list[int], target: int) -> bool:
        """
        Returns `True` if `target` is present as an element anywhere in `array`.

        Arguments
        - array: an array of `byte` values, possibly empty
        - target: a primitive `byte` value

        Returns
        - `True` if `array[i] == target` for some value of `i`
        """
        ...


    @staticmethod
    def indexOf(array: list[int], target: int) -> int:
        """
        Returns the index of the first appearance of the value `target` in `array`.

        Arguments
        - array: an array of `byte` values, possibly empty
        - target: a primitive `byte` value

        Returns
        - the least index `i` for which `array[i] == target`, or `-1` if no
            such index exists.
        """
        ...


    @staticmethod
    def indexOf(array: list[int], target: list[int]) -> int:
        """
        Returns the start position of the first occurrence of the specified `target` within
        `array`, or `-1` if there is no such occurrence.
        
        More formally, returns the lowest index `i` such that `Arrays.copyOfRange(array,
        i, i + target.length)` contains exactly the same elements as `target`.

        Arguments
        - array: the array to search for the sequence `target`
        - target: the array to search for as a sub-sequence of `array`
        """
        ...


    @staticmethod
    def lastIndexOf(array: list[int], target: int) -> int:
        """
        Returns the index of the last appearance of the value `target` in `array`.

        Arguments
        - array: an array of `byte` values, possibly empty
        - target: a primitive `byte` value

        Returns
        - the greatest index `i` for which `array[i] == target`, or `-1` if no
            such index exists.
        """
        ...


    @staticmethod
    def concat(*arrays: Tuple[list[int], ...]) -> list[int]:
        """
        Returns the values from each provided array combined into a single array. For example, `concat(new byte[] {a, b`, new byte[] {}, new byte[] {c}} returns the array `{a, b, c`}.

        Arguments
        - arrays: zero or more `byte` arrays

        Returns
        - a single array containing all the values from the source arrays, in order

        Raises
        - IllegalArgumentException: if the total number of elements in `arrays` does not fit
            in an `int`
        """
        ...


    @staticmethod
    def ensureCapacity(array: list[int], minLength: int, padding: int) -> list[int]:
        """
        Returns an array containing the same values as `array`, but guaranteed to be of a
        specified minimum length. If `array` already has a length of at least `minLength`,
        it is returned directly. Otherwise, a new array of size `minLength + padding` is
        returned, containing the values of `array`, and zeroes in the remaining places.

        Arguments
        - array: the source array
        - minLength: the minimum length the returned array must guarantee
        - padding: an extra amount to "grow" the array by if growth is necessary

        Returns
        - an array containing the values of `array`, with guaranteed minimum length `minLength`

        Raises
        - IllegalArgumentException: if `minLength` or `padding` is negative
        """
        ...


    @staticmethod
    def toArray(collection: Iterable["Number"]) -> list[int]:
        """
        Returns an array containing each value of `collection`, converted to a `byte` value
        in the manner of Number.byteValue.
        
        Elements are copied from the argument collection as if by `collection.toArray()`.
        Calling this method is as thread-safe as calling that method.

        Arguments
        - collection: a collection of `Number` instances

        Returns
        - an array containing the same values as `collection`, in the same order, converted
            to primitives

        Raises
        - NullPointerException: if `collection` or any of its elements is null

        Since
        - 1.0 (parameter was `Collection<Byte>` before 12.0)
        """
        ...


    @staticmethod
    def asList(*backingArray: Tuple[int, ...]) -> list["Byte"]:
        """
        Returns a fixed-size list backed by the specified array, similar to Arrays.asList(Object[]). The list supports List.set(int, Object), but any attempt to
        set a value to `null` will result in a NullPointerException.
        
        The returned list maintains the values, but not the identities, of `Byte` objects
        written to or read from it. For example, whether `list.get(0) == list.get(0)` is True for
        the returned list is unspecified.
        
        The returned list is serializable.

        Arguments
        - backingArray: the array to back the list

        Returns
        - a list view of the array
        """
        ...


    @staticmethod
    def reverse(array: list[int]) -> None:
        """
        Reverses the elements of `array`. This is equivalent to `Collections.reverse(Bytes.asList(array))`, but is likely to be more efficient.

        Since
        - 23.1
        """
        ...


    @staticmethod
    def reverse(array: list[int], fromIndex: int, toIndex: int) -> None:
        """
        Reverses the elements of `array` between `fromIndex` inclusive and `toIndex`
        exclusive. This is equivalent to `Collections.reverse(Bytes.asList(array).subList(fromIndex, toIndex))`, but is likely to be more
        efficient.

        Raises
        - IndexOutOfBoundsException: if `fromIndex < 0`, `toIndex > array.length`, or
            `toIndex > fromIndex`

        Since
        - 23.1
        """
        ...


    @staticmethod
    def rotate(array: list[int], distance: int) -> None:
        """
        Performs a right rotation of `array` of "distance" places, so that the first element is
        moved to index "distance", and the element at index `i` ends up at index `(distance
        + i) mod array.length`. This is equivalent to `Collections.rotate(Bytes.asList(array),
        distance)`, but is somewhat faster.
        
        The provided "distance" may be negative, which will rotate left.

        Since
        - 32.0.0
        """
        ...


    @staticmethod
    def rotate(array: list[int], distance: int, fromIndex: int, toIndex: int) -> None:
        """
        Performs a right rotation of `array` between `fromIndex` inclusive and `toIndex` exclusive. This is equivalent to `Collections.rotate(Bytes.asList(array).subList(fromIndex, toIndex), distance)`, but is somewhat
        faster.
        
        The provided "distance" may be negative, which will rotate left.

        Raises
        - IndexOutOfBoundsException: if `fromIndex < 0`, `toIndex > array.length`, or
            `toIndex > fromIndex`

        Since
        - 32.0.0
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.Dropper

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import *
from org.bukkit.loot import Lootable
from typing import Any, Callable, Iterable, Tuple


class Dropper(Container, Lootable):
    """
    Represents a captured state of a dropper.
    """

    def drop(self) -> None:
        """
        Tries to drop a randomly selected item from the dropper's inventory,
        following the normal behavior of a dropper.
        
        Normal behavior of a dropper is as follows:
        
        If the block that the dropper is facing is an InventoryHolder,
        the randomly selected ItemStack is placed within that
        Inventory in the first slot that's available, starting with 0 and
        counting up.  If the inventory is full, nothing happens.
        
        If the block that the dropper is facing is not an InventoryHolder,
        the randomly selected ItemStack is dropped on
        the ground in the form of an org.bukkit.entity.Item Item.
        
        If the block represented by this state is no longer a dropper, this will
        do nothing.

        Raises
        - IllegalStateException: if this block state is not placed
        """
        ...



"""
Python module generated from Java source file com.google.gson.internal.LazilyParsedNumber

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal import *
from java.io import IOException
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import ObjectStreamException
from java.math import BigDecimal
from typing import Any, Callable, Iterable, Tuple


class LazilyParsedNumber(Number):
    """
    This class holds a number value that is lazily converted to a specific number type

    Author(s)
    - Inderjeet Singh
    """

    def __init__(self, value: str):
        """
        Arguments
        - value: must not be null
        """
        ...


    def intValue(self) -> int:
        ...


    def longValue(self) -> int:
        ...


    def floatValue(self) -> float:
        ...


    def doubleValue(self) -> float:
        ...


    def toString(self) -> str:
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...



"""
Python module generated from Java source file com.google.gson.TypeAdapter

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from com.google.gson.internal.bind import JsonTreeReader
from com.google.gson.internal.bind import JsonTreeWriter
from com.google.gson.stream import JsonReader
from com.google.gson.stream import JsonToken
from com.google.gson.stream import JsonWriter
from java.io import IOException
from java.io import Reader
from java.io import StringReader
from java.io import StringWriter
from java.io import Writer
from typing import Any, Callable, Iterable, Tuple


class TypeAdapter:

    def __init__(self):
        ...


    def write(self, out: "JsonWriter", value: "T") -> None:
        """
        Writes one JSON value (an array, object, string, number, boolean or null) for `value`.

        Arguments
        - value: the Java object to write. May be null.
        """
        ...


    def toJson(self, out: "Writer", value: "T") -> None:
        """
        Converts `value` to a JSON document and writes it to `out`.
        
        A JsonWriter with default configuration is used for writing the JSON data. To
        customize this behavior, create a JsonWriter, configure it and then use .write(JsonWriter, Object) instead.

        Arguments
        - value: the Java object to convert. May be `null`.

        Since
        - 2.2
        """
        ...


    def toJson(self, value: "T") -> str:
        """
        Converts `value` to a JSON document.
        
        A JsonWriter with default configuration is used for writing the JSON data. To
        customize this behavior, create a JsonWriter, configure it and then use .write(JsonWriter, Object) instead.

        Arguments
        - value: the Java object to convert. May be `null`.

        Raises
        - JsonIOException: wrapping `IOException`s thrown by .write(JsonWriter,
            Object)

        Since
        - 2.2
        """
        ...


    def toJsonTree(self, value: "T") -> "JsonElement":
        """
        Converts `value` to a JSON tree.

        Arguments
        - value: the Java object to convert. May be `null`.

        Returns
        - the converted JSON tree. May be JsonNull.

        Raises
        - JsonIOException: wrapping `IOException`s thrown by .write(JsonWriter,
            Object)

        Since
        - 2.2
        """
        ...


    def read(self, in: "JsonReader") -> "T":
        """
        Reads one JSON value (an array, object, string, number, boolean or null) and converts it to a
        Java object. Returns the converted object.

        Returns
        - the converted Java object. May be `null`.
        """
        ...


    def fromJson(self, in: "Reader") -> "T":
        """
        Converts the JSON document in `in` to a Java object.
        
        A JsonReader with default configuration (that is with Strictness.LEGACY_STRICT as strictness) is used for reading the JSON data. To customize this
        behavior, create a JsonReader, configure it and then use .read(JsonReader)
        instead.
        
        No exception is thrown if the JSON data has multiple top-level JSON elements, or if there is
        trailing data.

        Returns
        - the converted Java object. May be `null`.

        Since
        - 2.2
        """
        ...


    def fromJson(self, json: str) -> "T":
        """
        Converts the JSON document in `json` to a Java object.
        
        A JsonReader with default configuration (that is with Strictness.LEGACY_STRICT as strictness) is used for reading the JSON data. To customize this
        behavior, create a JsonReader, configure it and then use .read(JsonReader)
        instead.
        
        No exception is thrown if the JSON data has multiple top-level JSON elements, or if there is
        trailing data.

        Returns
        - the converted Java object. May be `null`.

        Since
        - 2.2
        """
        ...


    def fromJsonTree(self, jsonTree: "JsonElement") -> "T":
        """
        Converts `jsonTree` to a Java object.

        Arguments
        - jsonTree: the JSON element to convert. May be JsonNull.

        Returns
        - the converted Java object. May be `null`.

        Raises
        - JsonIOException: wrapping `IOException`s thrown by .read(JsonReader)

        Since
        - 2.2
        """
        ...


    def nullSafe(self) -> "TypeAdapter"["T"]:
        """
        This wrapper method is used to make a type adapter null tolerant. In general, a type adapter is
        required to handle nulls in write and read methods. Here is how this is typically done:
        
        ````Gson gson = new GsonBuilder().registerTypeAdapter(Foo.class,
          new TypeAdapter<Foo>() {
            public Foo read(JsonReader in) throws IOException {
              if (in.peek() == JsonToken.NULL) {
                in.nextNull();
                return null;`
              // read a Foo from in and return it
            }
            public void write(JsonWriter out, Foo src) throws IOException {
              if (src == null) {
                out.nullValue();
                return;
              }
              // write src as JSON to out
            }
          }).create();
        }```
        
        You can avoid this boilerplate handling of nulls by wrapping your type adapter with this
        method. Here is how we will rewrite the above example:
        
        ````Gson gson = new GsonBuilder().registerTypeAdapter(Foo.class,
          new TypeAdapter<Foo>() {
            public Foo read(JsonReader in) throws IOException {
              // read a Foo from in and return it`
            public void write(JsonWriter out, Foo src) throws IOException {
              // write src as JSON to out
            }
          }.nullSafe()).create();
        }```
        
        Note that we didn't need to check for nulls in our type adapter after we used nullSafe.
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.RateLimiter

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.base import Stopwatch
from com.google.common.util.concurrent import *
from com.google.common.util.concurrent.SmoothRateLimiter import SmoothBursty
from com.google.common.util.concurrent.SmoothRateLimiter import SmoothWarmingUp
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.time import Duration
from java.util import Locale
from java.util.concurrent import TimeUnit
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class RateLimiter:

    @staticmethod
    def create(permitsPerSecond: float) -> "RateLimiter":
        ...


    @staticmethod
    def create(permitsPerSecond: float, warmupPeriod: "Duration") -> "RateLimiter":
        """
        Creates a `RateLimiter` with the specified stable throughput, given as "permits per
        second" (commonly referred to as *QPS*, queries per second), and a *warmup period*,
        during which the `RateLimiter` smoothly ramps up its rate, until it reaches its maximum
        rate at the end of the period (as long as there are enough requests to saturate it). Similarly,
        if the `RateLimiter` is left *unused* for a duration of `warmupPeriod`, it
        will gradually return to its "cold" state, i.e. it will go through the same warming up process
        as when it was first created.
        
        The returned `RateLimiter` is intended for cases where the resource that actually
        fulfills the requests (e.g., a remote server) needs "warmup" time, rather than being
        immediately accessed at the stable (maximum) rate.
        
        The returned `RateLimiter` starts in a "cold" state (i.e. the warmup period will
        follow), and if it is left unused for long enough, it will return to that state.

        Arguments
        - permitsPerSecond: the rate of the returned `RateLimiter`, measured in how many
            permits become available per second
        - warmupPeriod: the duration of the period where the `RateLimiter` ramps up its rate,
            before reaching its stable (maximum) rate

        Raises
        - IllegalArgumentException: if `permitsPerSecond` is negative or zero or `warmupPeriod` is negative

        Since
        - 28.0
        """
        ...


    @staticmethod
    def create(permitsPerSecond: float, warmupPeriod: int, unit: "TimeUnit") -> "RateLimiter":
        """
        Creates a `RateLimiter` with the specified stable throughput, given as "permits per
        second" (commonly referred to as *QPS*, queries per second), and a *warmup period*,
        during which the `RateLimiter` smoothly ramps up its rate, until it reaches its maximum
        rate at the end of the period (as long as there are enough requests to saturate it). Similarly,
        if the `RateLimiter` is left *unused* for a duration of `warmupPeriod`, it
        will gradually return to its "cold" state, i.e. it will go through the same warming up process
        as when it was first created.
        
        The returned `RateLimiter` is intended for cases where the resource that actually
        fulfills the requests (e.g., a remote server) needs "warmup" time, rather than being
        immediately accessed at the stable (maximum) rate.
        
        The returned `RateLimiter` starts in a "cold" state (i.e. the warmup period will
        follow), and if it is left unused for long enough, it will return to that state.

        Arguments
        - permitsPerSecond: the rate of the returned `RateLimiter`, measured in how many
            permits become available per second
        - warmupPeriod: the duration of the period where the `RateLimiter` ramps up its rate,
            before reaching its stable (maximum) rate
        - unit: the time unit of the warmupPeriod argument

        Raises
        - IllegalArgumentException: if `permitsPerSecond` is negative or zero or `warmupPeriod` is negative
        """
        ...


    def setRate(self, permitsPerSecond: float) -> None:
        """
        Updates the stable rate of this `RateLimiter`, that is, the `permitsPerSecond`
        argument provided in the factory method that constructed the `RateLimiter`. Currently
        throttled threads will **not** be awakened as a result of this invocation, thus they do not
        observe the new rate; only subsequent requests will.
        
        Note though that, since each request repays (by waiting, if necessary) the cost of the
        *previous* request, this means that the very next request after an invocation to `setRate` will not be affected by the new rate; it will pay the cost of the previous request,
        which is in terms of the previous rate.
        
        The behavior of the `RateLimiter` is not modified in any other way, e.g. if the `RateLimiter` was configured with a warmup period of 20 seconds, it still has a warmup period of
        20 seconds after this method invocation.

        Arguments
        - permitsPerSecond: the new stable rate of this `RateLimiter`

        Raises
        - IllegalArgumentException: if `permitsPerSecond` is negative or zero
        """
        ...


    def getRate(self) -> float:
        """
        Returns the stable rate (as `permits per seconds`) with which this `RateLimiter` is
        configured with. The initial value of this is the same as the `permitsPerSecond` argument
        passed in the factory method that produced this `RateLimiter`, and it is only updated
        after invocations to .setRate.
        """
        ...


    def acquire(self) -> float:
        """
        Acquires a single permit from this `RateLimiter`, blocking until the request can be
        granted. Tells the amount of time slept, if any.
        
        This method is equivalent to `acquire(1)`.

        Returns
        - time spent sleeping to enforce rate, in seconds; 0.0 if not rate-limited

        Since
        - 16.0 (present in 13.0 with `void` return type})
        """
        ...


    def acquire(self, permits: int) -> float:
        """
        Acquires the given number of permits from this `RateLimiter`, blocking until the request
        can be granted. Tells the amount of time slept, if any.

        Arguments
        - permits: the number of permits to acquire

        Returns
        - time spent sleeping to enforce rate, in seconds; 0.0 if not rate-limited

        Raises
        - IllegalArgumentException: if the requested number of permits is negative or zero

        Since
        - 16.0 (present in 13.0 with `void` return type})
        """
        ...


    def tryAcquire(self, timeout: "Duration") -> bool:
        """
        Acquires a permit from this `RateLimiter` if it can be obtained without exceeding the
        specified `timeout`, or returns `False` immediately (without waiting) if the permit
        would not have been granted before the timeout expired.
        
        This method is equivalent to `tryAcquire(1, timeout)`.

        Arguments
        - timeout: the maximum time to wait for the permit. Negative values are treated as zero.

        Returns
        - `True` if the permit was acquired, `False` otherwise

        Raises
        - IllegalArgumentException: if the requested number of permits is negative or zero

        Since
        - 28.0
        """
        ...


    def tryAcquire(self, timeout: int, unit: "TimeUnit") -> bool:
        """
        Acquires a permit from this `RateLimiter` if it can be obtained without exceeding the
        specified `timeout`, or returns `False` immediately (without waiting) if the permit
        would not have been granted before the timeout expired.
        
        This method is equivalent to `tryAcquire(1, timeout, unit)`.

        Arguments
        - timeout: the maximum time to wait for the permit. Negative values are treated as zero.
        - unit: the time unit of the timeout argument

        Returns
        - `True` if the permit was acquired, `False` otherwise

        Raises
        - IllegalArgumentException: if the requested number of permits is negative or zero
        """
        ...


    def tryAcquire(self, permits: int) -> bool:
        """
        Acquires permits from this RateLimiter if it can be acquired immediately without delay.
        
        This method is equivalent to `tryAcquire(permits, 0, anyUnit)`.

        Arguments
        - permits: the number of permits to acquire

        Returns
        - `True` if the permits were acquired, `False` otherwise

        Raises
        - IllegalArgumentException: if the requested number of permits is negative or zero

        Since
        - 14.0
        """
        ...


    def tryAcquire(self) -> bool:
        """
        Acquires a permit from this RateLimiter if it can be acquired immediately without
        delay.
        
        This method is equivalent to `tryAcquire(1)`.

        Returns
        - `True` if the permit was acquired, `False` otherwise

        Since
        - 14.0
        """
        ...


    def tryAcquire(self, permits: int, timeout: "Duration") -> bool:
        """
        Acquires the given number of permits from this `RateLimiter` if it can be obtained
        without exceeding the specified `timeout`, or returns `False` immediately (without
        waiting) if the permits would not have been granted before the timeout expired.

        Arguments
        - permits: the number of permits to acquire
        - timeout: the maximum time to wait for the permits. Negative values are treated as zero.

        Returns
        - `True` if the permits were acquired, `False` otherwise

        Raises
        - IllegalArgumentException: if the requested number of permits is negative or zero

        Since
        - 28.0
        """
        ...


    def tryAcquire(self, permits: int, timeout: int, unit: "TimeUnit") -> bool:
        """
        Acquires the given number of permits from this `RateLimiter` if it can be obtained
        without exceeding the specified `timeout`, or returns `False` immediately (without
        waiting) if the permits would not have been granted before the timeout expired.

        Arguments
        - permits: the number of permits to acquire
        - timeout: the maximum time to wait for the permits. Negative values are treated as zero.
        - unit: the time unit of the timeout argument

        Returns
        - `True` if the permits were acquired, `False` otherwise

        Raises
        - IllegalArgumentException: if the requested number of permits is negative or zero
        """
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.ExplosionResult

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class ExplosionResult(Enum):
    """
    Represents the outcome of an explosion.
    """

    KEEP = 0
    """
    Represents an explosion where no change took place.
    
    This is the case when org.bukkit.GameRule.MOB_GRIEFING is
    disabled.
    """
    DESTROY = 1
    """
    Represents an explosion where all destroyed blocks drop their items.
    
    This is the case when
    org.bukkit.GameRule.TNT_EXPLOSION_DROP_DECAY or
    org.bukkit.GameRule.BLOCK_EXPLOSION_DROP_DECAY is disabled.
    """
    DESTROY_WITH_DECAY = 2
    """
    Represents an explosion where explosions cause only some blocks to drop.
    """
    TRIGGER_BLOCK = 3
    """
    Represents an explosion where a block change/update has happened.
    
    For example, when a wind charge is used it will cause nearby buttons,
    levers and bells to be activated.
    """



"""
Python module generated from Java source file com.google.common.math.StatsAccumulator

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.math import *
from java.util import Iterator
from java.util.stream import DoubleStream
from java.util.stream import IntStream
from java.util.stream import LongStream
from typing import Any, Callable, Iterable, Tuple


class StatsAccumulator:
    """
    A mutable object which accumulates double values and tracks some basic statistics over all the
    values added so far. The values may be added singly or in groups. This class is not thread safe.

    Author(s)
    - Kevin Bourrillion

    Since
    - 20.0
    """

    def add(self, value: float) -> None:
        """
        Adds the given value to the dataset.
        """
        ...


    def addAll(self, values: Iterable["Number"]) -> None:
        """
        Adds the given values to the dataset.

        Arguments
        - values: a series of values, which will be converted to `double` values (this may
            cause loss of precision)
        """
        ...


    def addAll(self, values: Iterator["Number"]) -> None:
        """
        Adds the given values to the dataset.

        Arguments
        - values: a series of values, which will be converted to `double` values (this may
            cause loss of precision)
        """
        ...


    def addAll(self, *values: Tuple[float, ...]) -> None:
        """
        Adds the given values to the dataset.

        Arguments
        - values: a series of values
        """
        ...


    def addAll(self, *values: Tuple[int, ...]) -> None:
        """
        Adds the given values to the dataset.

        Arguments
        - values: a series of values
        """
        ...


    def addAll(self, *values: Tuple[int, ...]) -> None:
        """
        Adds the given values to the dataset.

        Arguments
        - values: a series of values, which will be converted to `double` values (this may
            cause loss of precision for longs of magnitude over 2^53 (slightly over 9e15))
        """
        ...


    def addAll(self, values: "DoubleStream") -> None:
        """
        Adds the given values to the dataset. The stream will be completely consumed by this method.

        Arguments
        - values: a series of values

        Since
        - 28.2
        """
        ...


    def addAll(self, values: "IntStream") -> None:
        """
        Adds the given values to the dataset. The stream will be completely consumed by this method.

        Arguments
        - values: a series of values

        Since
        - 28.2
        """
        ...


    def addAll(self, values: "LongStream") -> None:
        """
        Adds the given values to the dataset. The stream will be completely consumed by this method.

        Arguments
        - values: a series of values, which will be converted to `double` values (this may
            cause loss of precision for longs of magnitude over 2^53 (slightly over 9e15))

        Since
        - 28.2
        """
        ...


    def addAll(self, values: "Stats") -> None:
        """
        Adds the given statistics to the dataset, as if the individual values used to compute the
        statistics had been added directly.
        """
        ...


    def addAll(self, values: "StatsAccumulator") -> None:
        """
        Adds the given statistics to the dataset, as if the individual values used to compute the
        statistics had been added directly.

        Since
        - 28.2
        """
        ...


    def snapshot(self) -> "Stats":
        """
        Returns an immutable snapshot of the current statistics.
        """
        ...


    def count(self) -> int:
        """
        Returns the number of values.
        """
        ...


    def mean(self) -> float:
        """
        Returns the <a href="http://en.wikipedia.org/wiki/Arithmetic_mean">arithmetic mean</a> of the
        values. The count must be non-zero.
        
        If these values are a sample drawn from a population, this is also an unbiased estimator of
        the arithmetic mean of the population.
        
        <h3>Non-finite values</h3>
        
        If the dataset contains Double.NaN then the result is Double.NaN. If it
        contains both Double.POSITIVE_INFINITY and Double.NEGATIVE_INFINITY then the
        result is Double.NaN. If it contains Double.POSITIVE_INFINITY and finite values
        only or Double.POSITIVE_INFINITY only, the result is Double.POSITIVE_INFINITY.
        If it contains Double.NEGATIVE_INFINITY and finite values only or Double.NEGATIVE_INFINITY only, the result is Double.NEGATIVE_INFINITY.

        Raises
        - IllegalStateException: if the dataset is empty
        """
        ...


    def sum(self) -> float:
        """
        Returns the sum of the values.
        
        <h3>Non-finite values</h3>
        
        If the dataset contains Double.NaN then the result is Double.NaN. If it
        contains both Double.POSITIVE_INFINITY and Double.NEGATIVE_INFINITY then the
        result is Double.NaN. If it contains Double.POSITIVE_INFINITY and finite values
        only or Double.POSITIVE_INFINITY only, the result is Double.POSITIVE_INFINITY.
        If it contains Double.NEGATIVE_INFINITY and finite values only or Double.NEGATIVE_INFINITY only, the result is Double.NEGATIVE_INFINITY.
        """
        ...


    def populationVariance(self) -> float:
        """
        Returns the <a href="http://en.wikipedia.org/wiki/Variance#Population_variance">population
        variance</a> of the values. The count must be non-zero.
        
        This is guaranteed to return zero if the dataset contains only exactly one finite value. It
        is not guaranteed to return zero when the dataset consists of the same value multiple times,
        due to numerical errors. However, it is guaranteed never to return a negative result.
        
        <h3>Non-finite values</h3>
        
        If the dataset contains any non-finite values (Double.POSITIVE_INFINITY, Double.NEGATIVE_INFINITY, or Double.NaN) then the result is Double.NaN.

        Raises
        - IllegalStateException: if the dataset is empty
        """
        ...


    def populationStandardDeviation(self) -> float:
        """
        Returns the <a
        href="http://en.wikipedia.org/wiki/Standard_deviation#Definition_of_population_values">
        population standard deviation</a> of the values. The count must be non-zero.
        
        This is guaranteed to return zero if the dataset contains only exactly one finite value. It
        is not guaranteed to return zero when the dataset consists of the same value multiple times,
        due to numerical errors. However, it is guaranteed never to return a negative result.
        
        <h3>Non-finite values</h3>
        
        If the dataset contains any non-finite values (Double.POSITIVE_INFINITY, Double.NEGATIVE_INFINITY, or Double.NaN) then the result is Double.NaN.

        Raises
        - IllegalStateException: if the dataset is empty
        """
        ...


    def sampleVariance(self) -> float:
        """
        Returns the <a href="http://en.wikipedia.org/wiki/Variance#Sample_variance">unbiased sample
        variance</a> of the values. If this dataset is a sample drawn from a population, this is an
        unbiased estimator of the population variance of the population. The count must be greater than
        one.
        
        This is not guaranteed to return zero when the dataset consists of the same value multiple
        times, due to numerical errors. However, it is guaranteed never to return a negative result.
        
        <h3>Non-finite values</h3>
        
        If the dataset contains any non-finite values (Double.POSITIVE_INFINITY, Double.NEGATIVE_INFINITY, or Double.NaN) then the result is Double.NaN.

        Raises
        - IllegalStateException: if the dataset is empty or contains a single value
        """
        ...


    def sampleStandardDeviation(self) -> float:
        """
        Returns the <a
        href="http://en.wikipedia.org/wiki/Standard_deviation#Corrected_sample_standard_deviation">
        corrected sample standard deviation</a> of the values. If this dataset is a sample drawn from a
        population, this is an estimator of the population standard deviation of the population which
        is less biased than .populationStandardDeviation() (the unbiased estimator depends on
        the distribution). The count must be greater than one.
        
        This is not guaranteed to return zero when the dataset consists of the same value multiple
        times, due to numerical errors. However, it is guaranteed never to return a negative result.
        
        <h3>Non-finite values</h3>
        
        If the dataset contains any non-finite values (Double.POSITIVE_INFINITY, Double.NEGATIVE_INFINITY, or Double.NaN) then the result is Double.NaN.

        Raises
        - IllegalStateException: if the dataset is empty or contains a single value
        """
        ...


    def min(self) -> float:
        """
        Returns the lowest value in the dataset. The count must be non-zero.
        
        <h3>Non-finite values</h3>
        
        If the dataset contains Double.NaN then the result is Double.NaN. If it
        contains Double.NEGATIVE_INFINITY and not Double.NaN then the result is Double.NEGATIVE_INFINITY. If it contains Double.POSITIVE_INFINITY and finite values
        only then the result is the lowest finite value. If it contains Double.POSITIVE_INFINITY only then the result is Double.POSITIVE_INFINITY.

        Raises
        - IllegalStateException: if the dataset is empty
        """
        ...


    def max(self) -> float:
        """
        Returns the highest value in the dataset. The count must be non-zero.
        
        <h3>Non-finite values</h3>
        
        If the dataset contains Double.NaN then the result is Double.NaN. If it
        contains Double.POSITIVE_INFINITY and not Double.NaN then the result is Double.POSITIVE_INFINITY. If it contains Double.NEGATIVE_INFINITY and finite values
        only then the result is the highest finite value. If it contains Double.NEGATIVE_INFINITY only then the result is Double.NEGATIVE_INFINITY.

        Raises
        - IllegalStateException: if the dataset is empty
        """
        ...



"""
Python module generated from Java source file java.io.ObjectInputStream

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.io.ObjectInputFilter import Config
from java.io.ObjectStreamClass import RecordSupport
from java.io.ObjectStreamClass import WeakClassKey
from java.lang.System import Logger
from java.lang.invoke import MethodHandle
from java.lang.ref import ReferenceQueue
from java.lang.reflect import Array
from java.lang.reflect import InvocationHandler
from java.lang.reflect import Modifier
from java.lang.reflect import Proxy
from java.security import AccessControlContext
from java.security import AccessController
from java.security import PrivilegedAction
from java.security import PrivilegedActionException
from java.security import PrivilegedExceptionAction
from java.util import Arrays
from java.util import Objects
from java.util.concurrent import ConcurrentHashMap
from java.util.concurrent import ConcurrentMap
from jdk.internal.access import SharedSecrets
from jdk.internal.event import DeserializationEvent
from jdk.internal.misc import Unsafe
from sun.reflect.misc import ReflectUtil
from sun.security.action import GetBooleanAction
from sun.security.action import GetIntegerAction
from typing import Any, Callable, Iterable, Tuple


class ObjectInputStream(InputStream, ObjectInput, ObjectStreamConstants):
    """
    An ObjectInputStream deserializes primitive data and objects previously
    written using an ObjectOutputStream.
    
    <strong>Warning: Deserialization of untrusted data is inherently dangerous
    and should be avoided. Untrusted data should be carefully validated according to the
    "Serialization and Deserialization" section of the
    secure_coding_guidelines_javase Secure Coding Guidelines for Java SE.
    serialization_filter_guide Serialization Filtering describes best
    practices for defensive use of serial filters.
    </strong>
    
    The key to disabling deserialization attacks is to prevent instances of
    arbitrary classes from being deserialized, thereby preventing the direct or
    indirect execution of their methods.
    ObjectInputFilter describes how to use filters and
    ObjectInputFilter.Config describes how to configure the filter and filter factory.
    Each stream has an optional deserialization filter
    to check the classes and resource limits during deserialization.
    The JVM-wide filter factory ensures that a filter can be set on every ObjectInputStream
    and every object read from the stream can be checked.
    The .ObjectInputStream() ObjectInputStream constructors invoke the filter factory
    to select the initial filter which may be updated or replaced by .setObjectInputFilter.
    
    If an ObjectInputStream has a filter, the ObjectInputFilter can check that
    the classes, array lengths, number of references in the stream, depth, and
    number of bytes consumed from the input stream are allowed and
    if not, can terminate deserialization.
    
    ObjectOutputStream and ObjectInputStream can provide an application with
    persistent storage for graphs of objects when used with a FileOutputStream
    and FileInputStream respectively.  ObjectInputStream is used to recover
    those objects previously serialized. Other uses include passing objects
    between hosts using a socket stream or for marshaling and unmarshaling
    arguments and parameters in a remote communication system.
    
    ObjectInputStream ensures that the types of all objects in the graph
    created from the stream match the classes present in the Java Virtual
    Machine.  Classes are loaded as required using the standard mechanisms.
    
    Only objects that support the java.io.Serializable or
    java.io.Externalizable interface can be read from streams.
    
    The method `readObject` is used to read an object from the
    stream.  Java's safe casting should be used to get the desired type.  In
    Java, strings and arrays are objects and are treated as objects during
    serialization. When read they need to be cast to the expected type.
    
    Primitive data types can be read from the stream using the appropriate
    method on DataInput.
    
    The default deserialization mechanism for objects restores the contents
    of each field to the value and type it had when it was written.  Fields
    declared as transient or static are ignored by the deserialization process.
    References to other objects cause those objects to be read from the stream
    as necessary.  Graphs of objects are restored correctly using a reference
    sharing mechanism.  New objects are always allocated when deserializing,
    which prevents existing objects from being overwritten.
    
    Reading an object is analogous to running the constructors of a new
    object.  Memory is allocated for the object and initialized to zero (NULL).
    No-arg constructors are invoked for the non-serializable classes and then
    the fields of the serializable classes are restored from the stream starting
    with the serializable class closest to java.lang.object and finishing with
    the object's most specific class.
    
    For example to read from a stream as written by the example in
    ObjectOutputStream:
    
    ```
         FileInputStream fis = new FileInputStream("t.tmp");
         ObjectInputStream ois = new ObjectInputStream(fis);
    
         int i = ois.readInt();
         String today = (String) ois.readObject();
         Date date = (Date) ois.readObject();
    
         ois.close();
    ```
    
    Classes control how they are serialized by implementing either the
    java.io.Serializable or java.io.Externalizable interfaces.
    
    Implementing the Serializable interface allows object serialization to
    save and restore the entire state of the object and it allows classes to
    evolve between the time the stream is written and the time it is read.  It
    automatically traverses references between objects, saving and restoring
    entire graphs.
    
    Serializable classes that require special handling during the
    serialization and deserialization process should implement the following
    methods:
    
    ```
    private void writeObject(java.io.ObjectOutputStream stream)
        throws IOException;
    private void readObject(java.io.ObjectInputStream stream)
        throws IOException, ClassNotFoundException;
    private void readObjectNoData()
        throws ObjectStreamException;
    ```
    
    The readObject method is responsible for reading and restoring the state
    of the object for its particular class using data written to the stream by
    the corresponding writeObject method.  The method does not need to concern
    itself with the state belonging to its superclasses or subclasses.  State is
    restored by reading data from the ObjectInputStream for the individual
    fields and making assignments to the appropriate fields of the object.
    Reading primitive data types is supported by DataInput.
    
    Any attempt to read object data which exceeds the boundaries of the
    custom data written by the corresponding writeObject method will cause an
    OptionalDataException to be thrown with an eof field value of True.
    Non-object reads which exceed the end of the allotted data will reflect the
    end of data in the same way that they would indicate the end of the stream:
    bytewise reads will return -1 as the byte read or number of bytes read, and
    primitive reads will throw EOFExceptions.  If there is no corresponding
    writeObject method, then the end of default serialized data marks the end of
    the allotted data.
    
    Primitive and object read calls issued from within a readExternal method
    behave in the same manner--if the stream is already positioned at the end of
    data written by the corresponding writeExternal method, object reads will
    throw OptionalDataExceptions with eof set to True, bytewise reads will
    return -1, and primitive reads will throw EOFExceptions.  Note that this
    behavior does not hold for streams written with the old
    `ObjectStreamConstants.PROTOCOL_VERSION_1` protocol, in which the
    end of data written by writeExternal methods is not demarcated, and hence
    cannot be detected.
    
    The readObjectNoData method is responsible for initializing the state of
    the object for its particular class in the event that the serialization
    stream does not list the given class as a superclass of the object being
    deserialized.  This may occur in cases where the receiving party uses a
    different version of the deserialized instance's class than the sending
    party, and the receiver's version extends classes that are not extended by
    the sender's version.  This may also occur if the serialization stream has
    been tampered; hence, readObjectNoData is useful for initializing
    deserialized objects properly despite a "hostile" or incomplete source
    stream.
    
    Serialization does not read or assign values to the fields of any object
    that does not implement the java.io.Serializable interface.  Subclasses of
    Objects that are not serializable can be serializable. In this case the
    non-serializable class must have a no-arg constructor to allow its fields to
    be initialized.  In this case it is the responsibility of the subclass to
    save and restore the state of the non-serializable class. It is frequently
    the case that the fields of that class are accessible (public, package, or
    protected) or that there are get and set methods that can be used to restore
    the state.
    
    Any exception that occurs while deserializing an object will be caught by
    the ObjectInputStream and abort the reading process.
    
    Implementing the Externalizable interface allows the object to assume
    complete control over the contents and format of the object's serialized
    form.  The methods of the Externalizable interface, writeExternal and
    readExternal, are called to save and restore the objects state.  When
    implemented by a class they can write and read their own state using all of
    the methods of ObjectOutput and ObjectInput.  It is the responsibility of
    the objects to handle any versioning that occurs.
    
    Enum constants are deserialized differently than ordinary serializable or
    externalizable objects.  The serialized form of an enum constant consists
    solely of its name; field values of the constant are not transmitted.  To
    deserialize an enum constant, ObjectInputStream reads the constant name from
    the stream; the deserialized constant is then obtained by calling the static
    method `Enum.valueOf(Class, String)` with the enum constant's
    base type and the received constant name as arguments.  Like other
    serializable or externalizable objects, enum constants can function as the
    targets of back references appearing subsequently in the serialization
    stream.  The process by which enum constants are deserialized cannot be
    customized: any class-specific readObject, readObjectNoData, and readResolve
    methods defined by enum types are ignored during deserialization.
    Similarly, any serialPersistentFields or serialVersionUID field declarations
    are also ignored--all enum types have a fixed serialVersionUID of 0L.
    
    <a id="record-serialization"></a>
    Records are serialized differently than ordinary serializable or externalizable
    objects. During deserialization the record's canonical constructor is invoked
    to construct the record object. Certain serialization-related methods, such
    as readObject and writeObject, are ignored for serializable records. See
    <a href="/../specs/serialization/serial-arch.html#serialization-of-records">
    <cite>Java Object Serialization Specification,</cite> Section 1.13,
    "Serialization of Records"</a> for additional information.

    Author(s)
    - Roger Riggs

    See
    - <a href="/../specs/serialization/input.html">
         <cite>Java Object Serialization Specification,</cite> Section 3, "Object Input Classes"</a>

    Since
    - 1.1
    """

    def __init__(self, in: "InputStream"):
        """
        Creates an ObjectInputStream that reads from the specified InputStream.
        A serialization stream header is read from the stream and verified.
        This constructor will block until the corresponding ObjectOutputStream
        has written and flushed the header.
        
        The constructor initializes the deserialization filter to the filter returned
        by invoking the Config.getSerialFilterFactory() with `null` for the current filter
        and the Config.getSerialFilter() static JVM-wide filter for the requested filter.
        
        If a security manager is installed, this constructor will check for
        the "enableSubclassImplementation" SerializablePermission when invoked
        directly or indirectly by the constructor of a subclass which overrides
        the ObjectInputStream.readFields or ObjectInputStream.readUnshared
        methods.

        Arguments
        - in: input stream to read from

        Raises
        - StreamCorruptedException: if the stream header is incorrect
        - IOException: if an I/O error occurs while reading stream header
        - SecurityException: if untrusted subclass illegally overrides
                 security-sensitive methods
        - NullPointerException: if `in` is `null`

        See
        - ObjectOutputStream.ObjectOutputStream(OutputStream)
        """
        ...


    def readObject(self) -> "Object":
        """
        Read an object from the ObjectInputStream.  The class of the object, the
        signature of the class, and the values of the non-transient and
        non-static fields of the class and all of its supertypes are read.
        Default deserializing for a class can be overridden using the writeObject
        and readObject methods.  Objects referenced by this object are read
        transitively so that a complete equivalent graph of objects is
        reconstructed by readObject.
        
        The root object is completely restored when all of its fields and the
        objects it references are completely restored.  At this point the object
        validation callbacks are executed in order based on their registered
        priorities. The callbacks are registered by objects (in the readObject
        special methods) as they are individually restored.
        
        The deserialization filter, when not `null`, is invoked for
        each object (regular or class) read to reconstruct the root object.
        See .setObjectInputFilter(ObjectInputFilter) setObjectInputFilter for details.
        
        Exceptions are thrown for problems with the InputStream and for
        classes that should not be deserialized.  All exceptions are fatal to
        the InputStream and leave it in an indeterminate state; it is up to the
        caller to ignore or recover the stream state.

        Raises
        - ClassNotFoundException: Class of a serialized object cannot be
                 found.
        - InvalidClassException: Something is wrong with a class used by
                 deserialization.
        - StreamCorruptedException: Control information in the
                 stream is inconsistent.
        - OptionalDataException: Primitive data was found in the
                 stream instead of objects.
        - IOException: Any of the usual Input/Output related exceptions.
        """
        ...


    def readUnshared(self) -> "Object":
        """
        Reads an "unshared" object from the ObjectInputStream.  This method is
        identical to readObject, except that it prevents subsequent calls to
        readObject and readUnshared from returning additional references to the
        deserialized instance obtained via this call.  Specifically:
        
          - If readUnshared is called to deserialize a back-reference (the
              stream representation of an object which has been written
              previously to the stream), an ObjectStreamException will be
              thrown.
        
          - If readUnshared returns successfully, then any subsequent attempts
              to deserialize back-references to the stream handle deserialized
              by readUnshared will cause an ObjectStreamException to be thrown.
        
        Deserializing an object via readUnshared invalidates the stream handle
        associated with the returned object.  Note that this in itself does not
        always guarantee that the reference returned by readUnshared is unique;
        the deserialized object may define a readResolve method which returns an
        object visible to other parties, or readUnshared may return a Class
        object or enum constant obtainable elsewhere in the stream or through
        external means. If the deserialized object defines a readResolve method
        and the invocation of that method returns an array, then readUnshared
        returns a shallow clone of that array; this guarantees that the returned
        array object is unique and cannot be obtained a second time from an
        invocation of readObject or readUnshared on the ObjectInputStream,
        even if the underlying data stream has been manipulated.
        
        The deserialization filter, when not `null`, is invoked for
        each object (regular or class) read to reconstruct the root object.
        See .setObjectInputFilter(ObjectInputFilter) setObjectInputFilter for details.
        
        ObjectInputStream subclasses which override this method can only be
        constructed in security contexts possessing the
        "enableSubclassImplementation" SerializablePermission; any attempt to
        instantiate such a subclass without this permission will cause a
        SecurityException to be thrown.

        Returns
        - reference to deserialized object

        Raises
        - ClassNotFoundException: if class of an object to deserialize
                 cannot be found
        - StreamCorruptedException: if control information in the stream
                 is inconsistent
        - ObjectStreamException: if object to deserialize has already
                 appeared in stream
        - OptionalDataException: if primitive data is next in stream
        - IOException: if an I/O error occurs during deserialization

        Since
        - 1.4
        """
        ...


    def defaultReadObject(self) -> None:
        """
        Read the non-static and non-transient fields of the current class from
        this stream.  This may only be called from the readObject method of the
        class being deserialized. It will throw the NotActiveException if it is
        called otherwise.

        Raises
        - ClassNotFoundException: if the class of a serialized object
                 could not be found.
        - IOException: if an I/O error occurs.
        - NotActiveException: if the stream is not currently reading
                 objects.
        """
        ...


    def readFields(self) -> "ObjectInputStream.GetField":
        """
        Reads the persistent fields from the stream and makes them available by
        name.

        Returns
        - the `GetField` object representing the persistent
                 fields of the object being deserialized

        Raises
        - ClassNotFoundException: if the class of a serialized object
                 could not be found.
        - IOException: if an I/O error occurs.
        - NotActiveException: if the stream is not currently reading
                 objects.

        Since
        - 1.2
        """
        ...


    def registerValidation(self, obj: "ObjectInputValidation", prio: int) -> None:
        """
        Register an object to be validated before the graph is returned.  While
        similar to resolveObject these validations are called after the entire
        graph has been reconstituted.  Typically, a readObject method will
        register the object with the stream so that when all of the objects are
        restored a final set of validations can be performed.

        Arguments
        - obj: the object to receive the validation callback.
        - prio: controls the order of callbacks;zero is a good default.
                 Use higher numbers to be called back earlier, lower numbers for
                 later callbacks. Within a priority, callbacks are processed in
                 no particular order.

        Raises
        - NotActiveException: The stream is not currently reading objects
                 so it is invalid to register a callback.
        - InvalidObjectException: The validation object is null.
        """
        ...


    def read(self) -> int:
        """
        Reads a byte of data. This method will block if no input is available.

        Returns
        - the byte read, or -1 if the end of the stream is reached.

        Raises
        - IOException: If an I/O error has occurred.
        """
        ...


    def read(self, buf: list[int], off: int, len: int) -> int:
        """
        Reads into an array of bytes.  This method will block until some input
        is available. Consider using java.io.DataInputStream.readFully to read
        exactly 'length' bytes.

        Arguments
        - buf: the buffer into which the data is read
        - off: the start offset in the destination array `buf`
        - len: the maximum number of bytes read

        Returns
        - the actual number of bytes read, -1 is returned when the end of
                 the stream is reached.

        Raises
        - NullPointerException: if `buf` is `null`.
        - IndexOutOfBoundsException: if `off` is negative,
                 `len` is negative, or `len` is greater than
                 `buf.length - off`.
        - IOException: If an I/O error has occurred.

        See
        - java.io.DataInputStream.readFully(byte[],int,int)
        """
        ...


    def available(self) -> int:
        """
        Returns the number of bytes that can be read without blocking.

        Returns
        - the number of available bytes.

        Raises
        - IOException: if there are I/O errors while reading from the
                 underlying `InputStream`
        """
        ...


    def close(self) -> None:
        """
        Closes the input stream. Must be called to release any resources
        associated with the stream.

        Raises
        - IOException: If an I/O error has occurred.
        """
        ...


    def readBoolean(self) -> bool:
        """
        Reads in a boolean.

        Returns
        - the boolean read.

        Raises
        - EOFException: If end of file is reached.
        - IOException: If other I/O error has occurred.
        """
        ...


    def readByte(self) -> int:
        """
        Reads an 8 bit byte.

        Returns
        - the 8 bit byte read.

        Raises
        - EOFException: If end of file is reached.
        - IOException: If other I/O error has occurred.
        """
        ...


    def readUnsignedByte(self) -> int:
        """
        Reads an unsigned 8 bit byte.

        Returns
        - the 8 bit byte read.

        Raises
        - EOFException: If end of file is reached.
        - IOException: If other I/O error has occurred.
        """
        ...


    def readChar(self) -> str:
        """
        Reads a 16 bit char.

        Returns
        - the 16 bit char read.

        Raises
        - EOFException: If end of file is reached.
        - IOException: If other I/O error has occurred.
        """
        ...


    def readShort(self) -> int:
        """
        Reads a 16 bit short.

        Returns
        - the 16 bit short read.

        Raises
        - EOFException: If end of file is reached.
        - IOException: If other I/O error has occurred.
        """
        ...


    def readUnsignedShort(self) -> int:
        """
        Reads an unsigned 16 bit short.

        Returns
        - the 16 bit short read.

        Raises
        - EOFException: If end of file is reached.
        - IOException: If other I/O error has occurred.
        """
        ...


    def readInt(self) -> int:
        """
        Reads a 32 bit int.

        Returns
        - the 32 bit integer read.

        Raises
        - EOFException: If end of file is reached.
        - IOException: If other I/O error has occurred.
        """
        ...


    def readLong(self) -> int:
        """
        Reads a 64 bit long.

        Returns
        - the read 64 bit long.

        Raises
        - EOFException: If end of file is reached.
        - IOException: If other I/O error has occurred.
        """
        ...


    def readFloat(self) -> float:
        """
        Reads a 32 bit float.

        Returns
        - the 32 bit float read.

        Raises
        - EOFException: If end of file is reached.
        - IOException: If other I/O error has occurred.
        """
        ...


    def readDouble(self) -> float:
        """
        Reads a 64 bit double.

        Returns
        - the 64 bit double read.

        Raises
        - EOFException: If end of file is reached.
        - IOException: If other I/O error has occurred.
        """
        ...


    def readFully(self, buf: list[int]) -> None:
        """
        Reads bytes, blocking until all bytes are read.

        Arguments
        - buf: the buffer into which the data is read

        Raises
        - NullPointerException: If `buf` is `null`.
        - EOFException: If end of file is reached.
        - IOException: If other I/O error has occurred.
        """
        ...


    def readFully(self, buf: list[int], off: int, len: int) -> None:
        """
        Reads bytes, blocking until all bytes are read.

        Arguments
        - buf: the buffer into which the data is read
        - off: the start offset into the data array `buf`
        - len: the maximum number of bytes to read

        Raises
        - NullPointerException: If `buf` is `null`.
        - IndexOutOfBoundsException: If `off` is negative,
                 `len` is negative, or `len` is greater than
                 `buf.length - off`.
        - EOFException: If end of file is reached.
        - IOException: If other I/O error has occurred.
        """
        ...


    def skipBytes(self, len: int) -> int:
        """
        Skips bytes.

        Arguments
        - len: the number of bytes to be skipped

        Returns
        - the actual number of bytes skipped.

        Raises
        - IOException: If an I/O error has occurred.
        """
        ...


    def readLine(self) -> str:
        """
        Reads in a line that has been terminated by a \n, \r, \r\n or EOF.

        Returns
        - a String copy of the line.

        Raises
        - IOException: if there are I/O errors while reading from the
                 underlying `InputStream`

        Deprecated
        - This method does not properly convert bytes to characters.
                 see DataInputStream for the details and alternatives.
        """
        ...


    def readUTF(self) -> str:
        """
        Reads a String in
        <a href="DataInput.html#modified-utf-8">modified UTF-8</a>
        format.

        Returns
        - the String.

        Raises
        - IOException: if there are I/O errors while reading from the
                 underlying `InputStream`
        - UTFDataFormatException: if read bytes do not represent a valid
                 modified UTF-8 encoding of a string
        """
        ...


    def getObjectInputFilter(self) -> "ObjectInputFilter":
        """
        Returns the deserialization filter for this stream.
        The filter is the result of invoking the
        Config.getSerialFilterFactory() JVM-wide filter factory
        either by the .ObjectInputStream() constructor or the most recent invocation of
        .setObjectInputFilter setObjectInputFilter.

        Returns
        - the deserialization filter for the stream; may be null

        Since
        - 9
        """
        ...


    def setObjectInputFilter(self, filter: "ObjectInputFilter") -> None:
        """
        Set the deserialization filter for the stream.
        
        The deserialization filter is set to the filter returned by invoking the
        Config.getSerialFilterFactory() JVM-wide filter factory
        with the .getObjectInputFilter() current filter and the `filter` parameter.
        The current filter was set in the
        .ObjectInputStream() ObjectInputStream constructors by invoking the
        Config.getSerialFilterFactory() JVM-wide filter factory and may be `null`.
        .setObjectInputFilter(ObjectInputFilter) This method} can be called
        once and only once before reading any objects from the stream;
        for example, by calling .readObject or .readUnshared.
        
        It is not permitted to replace a `non-null` filter with a `null` filter.
        If the .getObjectInputFilter() current filter is `non-null`,
        the value returned from the filter factory must be `non-null`.
        
        The filter's ObjectInputFilter.checkInput checkInput method is called
        for each class and reference in the stream.
        The filter can check any or all of the class, the array length, the number
        of references, the depth of the graph, and the size of the input stream.
        The depth is the number of nested .readObject readObject
        calls starting with the reading of the root of the graph being deserialized
        and the current object being deserialized.
        The number of references is the cumulative number of objects and references
        to objects already read from the stream including the current object being read.
        The filter is invoked only when reading objects from the stream and not for
        primitives.
        
        If the filter returns ObjectInputFilter.Status.REJECTED Status.REJECTED,
        `null` or throws a RuntimeException,
        the active `readObject` or `readUnshared`
        throws InvalidClassException, otherwise deserialization
        continues uninterrupted.

        Arguments
        - filter: the filter, may be null

        Raises
        - SecurityException: if there is security manager and the
              `SerializablePermission("serialFilter")` is not granted
        - IllegalStateException: if an object has been read,
              if the filter factory returns `null` when the
              .getObjectInputFilter() current filter is non-null, or
              if the filter has already been set.

        Since
        - 9

        Unknown Tags
        - The filter, when not `null`, is invoked during .readObject readObject
        and .readUnshared readUnshared for each object (regular or class) in the stream.
        Strings are treated as primitives and do not invoke the filter.
        The filter is called for:
        
            - each object reference previously deserialized from the stream
            (class is `null`, arrayLength is -1),
            - each regular class (class is not `null`, arrayLength is -1),
            - each interface class explicitly referenced in the stream
                (it is not called for interfaces implemented by classes in the stream),
            - each interface of a dynamic proxy and the dynamic proxy class itself
            (class is not `null`, arrayLength is -1),
            - each array is filtered using the array type and length of the array
            (class is the array type, arrayLength is the requested length),
            - each object replaced by its class' `readResolve` method
                is filtered using the replacement object's class, if not `null`,
                and if it is an array, the arrayLength, otherwise -1,
            - and each object replaced by .resolveObject resolveObject
                is filtered using the replacement object's class, if not `null`,
                and if it is an array, the arrayLength, otherwise -1.
        
        
        When the ObjectInputFilter.checkInput checkInput method is invoked
        it is given access to the current class, the array length,
        the current number of references already read from the stream,
        the depth of nested calls to .readObject readObject or
        .readUnshared readUnshared,
        and the implementation dependent number of bytes consumed from the input stream.
        
        Each call to .readObject readObject or
        .readUnshared readUnshared increases the depth by 1
        before reading an object and decreases by 1 before returning
        normally or exceptionally.
        The depth starts at `1` and increases for each nested object and
        decrements when each nested call returns.
        The count of references in the stream starts at `1` and
        is increased before reading an object.
        """
        ...


    class GetField:
        """
        Provide access to the persistent fields read from the input stream.
        """

        def __init__(self):
            """
            Constructor for subclasses to call.
            """
            ...


        def getObjectStreamClass(self) -> "ObjectStreamClass":
            """
            Get the ObjectStreamClass that describes the fields in the stream.

            Returns
            - the descriptor class that describes the serializable fields
            """
            ...


        def defaulted(self, name: str) -> bool:
            """
            Return True if the named field is defaulted and has no value in this
            stream.

            Arguments
            - name: the name of the field

            Returns
            - True, if and only if the named field is defaulted

            Raises
            - IOException: if there are I/O errors while reading from
                    the underlying `InputStream`
            - IllegalArgumentException: if `name` does not
                    correspond to a serializable field
            """
            ...


        def get(self, name: str, val: bool) -> bool:
            """
            Get the value of the named boolean field from the persistent field.

            Arguments
            - name: the name of the field
            - val: the default value to use if `name` does not
                    have a value

            Returns
            - the value of the named `boolean` field

            Raises
            - IOException: if there are I/O errors while reading from the
                    underlying `InputStream`
            - IllegalArgumentException: if type of `name` is
                    not serializable or if the field type is incorrect
            """
            ...


        def get(self, name: str, val: int) -> int:
            """
            Get the value of the named byte field from the persistent field.

            Arguments
            - name: the name of the field
            - val: the default value to use if `name` does not
                    have a value

            Returns
            - the value of the named `byte` field

            Raises
            - IOException: if there are I/O errors while reading from the
                    underlying `InputStream`
            - IllegalArgumentException: if type of `name` is
                    not serializable or if the field type is incorrect
            """
            ...


        def get(self, name: str, val: str) -> str:
            """
            Get the value of the named char field from the persistent field.

            Arguments
            - name: the name of the field
            - val: the default value to use if `name` does not
                    have a value

            Returns
            - the value of the named `char` field

            Raises
            - IOException: if there are I/O errors while reading from the
                    underlying `InputStream`
            - IllegalArgumentException: if type of `name` is
                    not serializable or if the field type is incorrect
            """
            ...


        def get(self, name: str, val: int) -> int:
            """
            Get the value of the named short field from the persistent field.

            Arguments
            - name: the name of the field
            - val: the default value to use if `name` does not
                    have a value

            Returns
            - the value of the named `short` field

            Raises
            - IOException: if there are I/O errors while reading from the
                    underlying `InputStream`
            - IllegalArgumentException: if type of `name` is
                    not serializable or if the field type is incorrect
            """
            ...


        def get(self, name: str, val: int) -> int:
            """
            Get the value of the named int field from the persistent field.

            Arguments
            - name: the name of the field
            - val: the default value to use if `name` does not
                    have a value

            Returns
            - the value of the named `int` field

            Raises
            - IOException: if there are I/O errors while reading from the
                    underlying `InputStream`
            - IllegalArgumentException: if type of `name` is
                    not serializable or if the field type is incorrect
            """
            ...


        def get(self, name: str, val: int) -> int:
            """
            Get the value of the named long field from the persistent field.

            Arguments
            - name: the name of the field
            - val: the default value to use if `name` does not
                    have a value

            Returns
            - the value of the named `long` field

            Raises
            - IOException: if there are I/O errors while reading from the
                    underlying `InputStream`
            - IllegalArgumentException: if type of `name` is
                    not serializable or if the field type is incorrect
            """
            ...


        def get(self, name: str, val: float) -> float:
            """
            Get the value of the named float field from the persistent field.

            Arguments
            - name: the name of the field
            - val: the default value to use if `name` does not
                    have a value

            Returns
            - the value of the named `float` field

            Raises
            - IOException: if there are I/O errors while reading from the
                    underlying `InputStream`
            - IllegalArgumentException: if type of `name` is
                    not serializable or if the field type is incorrect
            """
            ...


        def get(self, name: str, val: float) -> float:
            """
            Get the value of the named double field from the persistent field.

            Arguments
            - name: the name of the field
            - val: the default value to use if `name` does not
                    have a value

            Returns
            - the value of the named `double` field

            Raises
            - IOException: if there are I/O errors while reading from the
                    underlying `InputStream`
            - IllegalArgumentException: if type of `name` is
                    not serializable or if the field type is incorrect
            """
            ...


        def get(self, name: str, val: "Object") -> "Object":
            """
            Get the value of the named Object field from the persistent field.

            Arguments
            - name: the name of the field
            - val: the default value to use if `name` does not
                    have a value

            Returns
            - the value of the named `Object` field

            Raises
            - IOException: if there are I/O errors while reading from the
                    underlying `InputStream`
            - IllegalArgumentException: if type of `name` is
                    not serializable or if the field type is incorrect
            """
            ...



"""
Python module generated from Java source file com.google.gson.internal.bind.MapTypeAdapterFactory

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import Gson
from com.google.gson import JsonElement
from com.google.gson import JsonPrimitive
from com.google.gson import JsonSyntaxException
from com.google.gson import TypeAdapter
from com.google.gson import TypeAdapterFactory
from com.google.gson.internal import $Gson$Types
from com.google.gson.internal import ConstructorConstructor
from com.google.gson.internal import JsonReaderInternalAccess
from com.google.gson.internal import ObjectConstructor
from com.google.gson.internal import Streams
from com.google.gson.internal.bind import *
from com.google.gson.reflect import TypeToken
from com.google.gson.stream import JsonReader
from com.google.gson.stream import JsonToken
from com.google.gson.stream import JsonWriter
from java.io import IOException
from java.lang.reflect import Type
from typing import Any, Callable, Iterable, Tuple


class MapTypeAdapterFactory(TypeAdapterFactory):
    """
    Adapts maps to either JSON objects or JSON arrays.
    
    <h2>Maps as JSON objects</h2>
    
    For primitive keys or when complex map key serialization is not enabled, this converts Java
    Map Maps to JSON Objects. This requires that map keys can be serialized as strings; this
    is insufficient for some key types. For example, consider a map whose keys are points on a grid.
    The default JSON form encodes reasonably:
    
    ````Map<Point, String> original = new LinkedHashMap<>();
    original.put(new Point(5, 6), "a");
    original.put(new Point(8, 8), "b");
    System.out.println(gson.toJson(original, type));````
    
    The above code prints this JSON object:
    
    ````{
      "(5,6)": "a",
      "(8,8)": "b"`
    }```
    
    But GSON is unable to deserialize this value because the JSON string name is just the Object.toString() toString() of the map key. Attempting to convert the above JSON to an object
    fails with a parse exception:
    
    ```com.google.gson.JsonParseException: Expecting object found: "(5,6)"
      at com.google.gson.JsonObjectDeserializationVisitor.visitFieldUsingCustomHandler
      at com.google.gson.ObjectNavigator.navigateClassFields
      ...```
    
    <h2>Maps as JSON arrays</h2>
    
    An alternative approach taken by this type adapter when it is required and complex map key
    serialization is enabled is to encode maps as arrays of map entries. Each map entry is a two
    element array containing a key and a value. This approach is more flexible because any type can
    be used as the map's key; not just strings. But it's also less portable because the receiver of
    such JSON must be aware of the map entry convention.
    
    Register this adapter when you are creating your GSON instance.
    
    ````Gson gson = new GsonBuilder()
      .registerTypeAdapter(Map.class, new MapAsArrayTypeAdapter())
      .create();````
    
    This will change the structure of the JSON emitted by the code above. Now we get an array. In
    this case the arrays elements are map entries:
    
    ````[
      [
        {
          "x": 5,
          "y": 6`,
        "a",
      ],
      [
        {
          "x": 8,
          "y": 8
        },
        "b"
      ]
    ]
    }```
    
    This format will serialize and deserialize just fine as long as this adapter is registered.
    """

    def __init__(self, constructorConstructor: "ConstructorConstructor", complexMapKeySerialization: bool):
        ...


    def create(self, gson: "Gson", typeToken: "TypeToken"["T"]) -> "TypeAdapter"["T"]:
        ...



"""
Python module generated from Java source file com.google.common.collect.RegularImmutableMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.collect import *
from com.google.common.collect.ImmutableMapEntry import NonTerminalImmutableMapEntry
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.io import Serializable
from java.util import IdentityHashMap
from java.util.function import BiConsumer
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class RegularImmutableMap(ImmutableMap):
    """
    Implementation of ImmutableMap used for 0 entries and for 2+ entries. Additional
    implementations exist for particular cases, like ImmutableTable views and hash flooding.
    (This doc discusses ImmutableMap subclasses only for the JRE flavor; the Android flavor
    differs.)

    Author(s)
    - Gregory Kick
    """

    def get(self, key: "Object") -> "V":
        ...


    def forEach(self, action: "BiConsumer"["K", "V"]) -> None:
        ...


    def size(self) -> int:
        ...



"""
Python module generated from Java source file org.bukkit.entity.Warden

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import Location
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Warden(Monster):
    """
    A Warden.
    """

    def getAnger(self) -> int:
        """
        Gets the anger level of this warden.
        
        Anger is an integer from 0 to 150. Once a Warden reaches 80 anger at a
        target it will actively pursue it.

        Returns
        - anger level
        """
        ...


    def getAnger(self, entity: "Entity") -> int:
        """
        Gets the anger level of this warden.
        
        Anger is an integer from 0 to 150. Once a Warden reaches 80 anger at a
        target it will actively pursue it.

        Arguments
        - entity: target entity

        Returns
        - anger level
        """
        ...


    def increaseAnger(self, entity: "Entity", increase: int) -> None:
        """
        Increases the anger level of this warden.
        
        Anger is an integer from 0 to 150. Once a Warden reaches 80 anger at a
        target it will actively pursue it.

        Arguments
        - entity: target entity
        - increase: number to increase by

        See
        - .getAnger(org.bukkit.entity.Entity)
        """
        ...


    def setAnger(self, entity: "Entity", anger: int) -> None:
        """
        Sets the anger level of this warden.
        
        Anger is an integer from 0 to 150. Once a Warden reaches 80 anger at a
        target it will actively pursue it.

        Arguments
        - entity: target entity
        - anger: new anger level

        See
        - .getAnger(org.bukkit.entity.Entity)
        """
        ...


    def clearAnger(self, entity: "Entity") -> None:
        """
        Clears the anger level of this warden.

        Arguments
        - entity: target entity
        """
        ...


    def getEntityAngryAt(self) -> "LivingEntity":
        """
        Gets the LivingEntity at which this warden is most angry.

        Returns
        - The target LivingEntity or null
        """
        ...


    def setDisturbanceLocation(self, location: "Location") -> None:
        """
        Make the warden sense a disturbance in the force at the location given.

        Arguments
        - location: location of the disturbance
        """
        ...


    def getAngerLevel(self) -> "AngerLevel":
        """
        Get the level of anger of this warden.

        Returns
        - The level of anger
        """
        ...


    class AngerLevel(Enum):

        CALM = 0
        """
        Anger level 0-39.
        """
        AGITATED = 1
        """
        Anger level 40-79.
        """
        ANGRY = 2
        """
        Anger level 80 or above.
        """



"""
Python module generated from Java source file org.bukkit.plugin.java.JavaPluginLoader

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from java.io import File
from java.io import FileNotFoundException
from java.io import IOException
from java.io import InputStream
from java.lang.reflect import InvocationTargetException
from java.lang.reflect import Method
from java.util import Arrays
from java.util.concurrent import CopyOnWriteArrayList
from java.util.jar import JarEntry
from java.util.jar import JarFile
from java.util.regex import Pattern
from org.bukkit import Server
from org.bukkit import Warning
from org.bukkit.Warning import WarningState
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.configuration.serialization import ConfigurationSerialization
from org.bukkit.event import Event
from org.bukkit.event import EventException
from org.bukkit.event import EventHandler
from org.bukkit.event import Listener
from org.bukkit.event.server import PluginDisableEvent
from org.bukkit.event.server import PluginEnableEvent
from org.bukkit.plugin import AuthorNagException
from org.bukkit.plugin import EventExecutor
from org.bukkit.plugin import InvalidDescriptionException
from org.bukkit.plugin import InvalidPluginException
from org.bukkit.plugin import Plugin
from org.bukkit.plugin import PluginDescriptionFile
from org.bukkit.plugin import PluginLoader
from org.bukkit.plugin import RegisteredListener
from org.bukkit.plugin import SimplePluginManager
from org.bukkit.plugin import TimedRegisteredListener
from org.bukkit.plugin import UnknownDependencyException
from org.bukkit.plugin.java import *
from org.spigotmc import CustomTimingsHandler
from org.yaml.snakeyaml.error import YAMLException
from typing import Any, Callable, Iterable, Tuple


class JavaPluginLoader(PluginLoader):
    """
    Represents a Java plugin loader, allowing plugins in the form of .jar
    """

    pluginParentTimer = CustomTimingsHandler("** Plugins")


    def __init__(self, instance: "Server"):
        """
        This class was not meant to be constructed explicitly

        Arguments
        - instance: the server instance
        """
        ...


    def loadPlugin(self, file: "File") -> "Plugin":
        ...


    def getPluginDescription(self, file: "File") -> "PluginDescriptionFile":
        ...


    def getPluginFileFilters(self) -> list["Pattern"]:
        ...


    def createRegisteredListeners(self, listener: "Listener", plugin: "Plugin") -> dict[type["Event"], set["RegisteredListener"]]:
        ...


    def enablePlugin(self, plugin: "Plugin") -> None:
        ...


    def disablePlugin(self, plugin: "Plugin") -> None:
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerInteractAtEntityEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Entity
from org.bukkit.entity import Player
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from org.bukkit.inventory import EquipmentSlot
from org.bukkit.util import Vector
from typing import Any, Callable, Iterable, Tuple


class PlayerInteractAtEntityEvent(PlayerInteractEntityEvent):
    """
    Represents an event that is called when a player right clicks an entity that
    also contains the location where the entity was clicked.
    
    Note that the client may sometimes spuriously send this packet in addition to PlayerInteractEntityEvent.
    Users are advised to listen to this (parent) class unless specifically required.
    """

    def __init__(self, who: "Player", clickedEntity: "Entity", position: "Vector"):
        ...


    def __init__(self, who: "Player", clickedEntity: "Entity", position: "Vector", hand: "EquipmentSlot"):
        ...


    def getClickedPosition(self) -> "Vector":
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



from .VerifyException import VerifyException
from .Verify import Verify
from .Utf8 import Utf8
from .Ticker import Ticker
from .Throwables import Throwables
from .Suppliers import Suppliers
from .Supplier import Supplier
from .Strings import Strings
from .Stopwatch import Stopwatch
from .StandardSystemProperty import StandardSystemProperty
from .Splitter import Splitter
from .SmallCharMatcher import SmallCharMatcher
from .Present import Present
from .Predicates import Predicates
from .Predicate import Predicate
from .Preconditions import Preconditions
from .Platform import Platform
from .PatternCompiler import PatternCompiler
from .ParametricNullness import ParametricNullness
from .PairwiseEquivalence import PairwiseEquivalence
from .Optional import Optional
from .Objects import Objects
from .NullnessCasts import NullnessCasts
from .MoreObjects import MoreObjects
from .Joiner import Joiner
from .JdkPattern import JdkPattern
from .Java8Compatibility import Java8Compatibility
from .Internal import Internal
from .IgnoreJRERequirement import IgnoreJRERequirement
from .Functions import Functions
from .FunctionalEquivalence import FunctionalEquivalence
from .Function import Function
from .FinalizableWeakReference import FinalizableWeakReference
from .FinalizableSoftReference import FinalizableSoftReference
from .FinalizableReferenceQueue import FinalizableReferenceQueue
from .FinalizableReference import FinalizableReference
from .FinalizablePhantomReference import FinalizablePhantomReference
from .ExtraObjectsMethodsForWeb import ExtraObjectsMethodsForWeb
from .Equivalence import Equivalence
from .Enums import Enums
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .Defaults import Defaults
from .Converter import Converter
from .CommonPattern import CommonPattern
from .CommonMatcher import CommonMatcher
from .Charsets import Charsets
from .CharMatcher import CharMatcher
from .CaseFormat import CaseFormat
from .Ascii import Ascii
from .AbstractIterator import AbstractIterator
from .Absent import Absent


"""
Python module generated from Java source file java.io.InputStreamReader

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.nio.charset import Charset
from java.nio.charset import CharsetDecoder
from sun.nio.cs import StreamDecoder
from typing import Any, Callable, Iterable, Tuple


class InputStreamReader(Reader):

    def __init__(self, in: "InputStream"):
        """
        Creates an InputStreamReader that uses the
        Charset.defaultCharset() default charset.

        Arguments
        - in: An InputStream

        See
        - Charset.defaultCharset()
        """
        ...


    def __init__(self, in: "InputStream", charsetName: str):
        """
        Creates an InputStreamReader that uses the named charset.

        Arguments
        - in: An InputStream
        - charsetName: The name of a supported
                java.nio.charset.Charset charset

        Raises
        - UnsupportedEncodingException: If the named charset is not supported
        """
        ...


    def __init__(self, in: "InputStream", cs: "Charset"):
        """
        Creates an InputStreamReader that uses the given charset.

        Arguments
        - in: An InputStream
        - cs: A charset

        Since
        - 1.4
        """
        ...


    def __init__(self, in: "InputStream", dec: "CharsetDecoder"):
        """
        Creates an InputStreamReader that uses the given charset decoder.

        Arguments
        - in: An InputStream
        - dec: A charset decoder

        Since
        - 1.4
        """
        ...


    def getEncoding(self) -> str:
        """
        Returns the name of the character encoding being used by this stream.
        
         If the encoding has an historical name then that name is returned;
        otherwise the encoding's canonical name is returned.
        
         If this instance was created with the .InputStreamReader(InputStream, String) constructor then the returned
        name, being unique for the encoding, may differ from the name passed to
        the constructor. This method will return `null` if the
        stream has been closed.

        Returns
        - The historical name of this encoding, or
                `null` if the stream has been closed

        See
        - java.nio.charset.Charset

        Unknown Tags
        - 1.4
        """
        ...


    def read(self, target: "CharBuffer") -> int:
        ...


    def read(self) -> int:
        """
        Reads a single character.

        Returns
        - The character read, or -1 if the end of the stream has been
                reached

        Raises
        - IOException: If an I/O error occurs
        """
        ...


    def read(self, cbuf: list[str], off: int, len: int) -> int:
        """
        Raises
        - IndexOutOfBoundsException: 
        """
        ...


    def ready(self) -> bool:
        """
        Tells whether this stream is ready to be read.  An InputStreamReader is
        ready if its input buffer is not empty, or if bytes are available to be
        read from the underlying byte stream.

        Raises
        - IOException: If an I/O error occurs
        """
        ...


    def close(self) -> None:
        ...



"""
Python module generated from Java source file java.util.stream.DoubleStream

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Arrays
from java.util import DoubleSummaryStatistics
from java.util import Objects
from java.util import OptionalDouble
from java.util import PrimitiveIterator
from java.util import Spliterator
from java.util.function import BiConsumer
from java.util.function import DoubleBinaryOperator
from java.util.function import DoubleConsumer
from java.util.function import DoubleFunction
from java.util.function import DoublePredicate
from java.util.function import DoubleSupplier
from java.util.function import DoubleToIntFunction
from java.util.function import DoubleToLongFunction
from java.util.function import DoubleUnaryOperator
from java.util.function import Function
from java.util.function import ObjDoubleConsumer
from java.util.function import Supplier
from java.util.stream import *
from typing import Any, Callable, Iterable, Tuple


class DoubleStream(BaseStream):
    """
    A sequence of primitive double-valued elements supporting sequential and parallel
    aggregate operations.  This is the `double` primitive specialization of
    Stream.
    
    The following example illustrates an aggregate operation using
    Stream and DoubleStream, computing the sum of the weights of the
    red widgets:
    
    ````double sum = widgets.stream()
                            .filter(w -> w.getColor() == RED)
                            .mapToDouble(w -> w.getWeight())
                            .sum();````
    
    See the class documentation for Stream and the package documentation
    for <a href="package-summary.html">java.util.stream</a> for additional
    specification of streams, stream operations, stream pipelines, and
    parallelism.

    See
    - <a href="package-summary.html">java.util.stream</a>

    Since
    - 1.8
    """

    def filter(self, predicate: "DoublePredicate") -> "DoubleStream":
        """
        Returns a stream consisting of the elements of this stream that match
        the given predicate.
        
        This is an <a href="package-summary.html#StreamOps">intermediate
        operation</a>.

        Arguments
        - predicate: a <a href="package-summary.html#NonInterference">non-interfering</a>,
                         <a href="package-summary.html#Statelessness">stateless</a>
                         predicate to apply to each element to determine if it
                         should be included

        Returns
        - the new stream
        """
        ...


    def map(self, mapper: "DoubleUnaryOperator") -> "DoubleStream":
        """
        Returns a stream consisting of the results of applying the given
        function to the elements of this stream.
        
        This is an <a href="package-summary.html#StreamOps">intermediate
        operation</a>.

        Arguments
        - mapper: a <a href="package-summary.html#NonInterference">non-interfering</a>,
                      <a href="package-summary.html#Statelessness">stateless</a>
                      function to apply to each element

        Returns
        - the new stream
        """
        ...


    def mapToObj(self, mapper: "DoubleFunction"["U"]) -> "Stream"["U"]:
        """
        Returns an object-valued `Stream` consisting of the results of
        applying the given function to the elements of this stream.
        
        This is an <a href="package-summary.html#StreamOps">
            intermediate operation</a>.
        
        Type `<U>`: the element type of the new stream

        Arguments
        - mapper: a <a href="package-summary.html#NonInterference">non-interfering</a>,
                      <a href="package-summary.html#Statelessness">stateless</a>
                      function to apply to each element

        Returns
        - the new stream
        """
        ...


    def mapToInt(self, mapper: "DoubleToIntFunction") -> "IntStream":
        """
        Returns an `IntStream` consisting of the results of applying the
        given function to the elements of this stream.
        
        This is an <a href="package-summary.html#StreamOps">intermediate
        operation</a>.

        Arguments
        - mapper: a <a href="package-summary.html#NonInterference">non-interfering</a>,
                      <a href="package-summary.html#Statelessness">stateless</a>
                      function to apply to each element

        Returns
        - the new stream
        """
        ...


    def mapToLong(self, mapper: "DoubleToLongFunction") -> "LongStream":
        """
        Returns a `LongStream` consisting of the results of applying the
        given function to the elements of this stream.
        
        This is an <a href="package-summary.html#StreamOps">intermediate
        operation</a>.

        Arguments
        - mapper: a <a href="package-summary.html#NonInterference">non-interfering</a>,
                      <a href="package-summary.html#Statelessness">stateless</a>
                      function to apply to each element

        Returns
        - the new stream
        """
        ...


    def flatMap(self, mapper: "DoubleFunction"["DoubleStream"]) -> "DoubleStream":
        """
        Returns a stream consisting of the results of replacing each element of
        this stream with the contents of a mapped stream produced by applying
        the provided mapping function to each element.  Each mapped stream is
        java.util.stream.BaseStream.close() closed after its contents
        have been placed into this stream.  (If a mapped stream is `null`
        an empty stream is used, instead.)
        
        This is an <a href="package-summary.html#StreamOps">intermediate
        operation</a>.

        Arguments
        - mapper: a <a href="package-summary.html#NonInterference">non-interfering</a>,
                      <a href="package-summary.html#Statelessness">stateless</a>
                      function to apply to each element which produces a
                      `DoubleStream` of new values

        Returns
        - the new stream

        See
        - Stream.flatMap(Function)
        """
        ...


    def mapMulti(self, mapper: "DoubleMapMultiConsumer") -> "DoubleStream":
        """
        Returns a stream consisting of the results of replacing each element of
        this stream with multiple elements, specifically zero or more elements.
        Replacement is performed by applying the provided mapping function to each
        element in conjunction with a DoubleConsumer consumer argument
        that accepts replacement elements. The mapping function calls the consumer
        zero or more times to provide the replacement elements.
        
        This is an <a href="package-summary.html#StreamOps">intermediate
        operation</a>.
        
        If the DoubleConsumer consumer argument is used outside the scope of
        its application to the mapping function, the results are undefined.

        Arguments
        - mapper: a <a href="package-summary.html#NonInterference">non-interfering</a>,
                      <a href="package-summary.html#Statelessness">stateless</a>
                      function that generates replacement elements

        Returns
        - the new stream

        See
        - Stream.mapMulti Stream.mapMulti

        Since
        - 16

        Unknown Tags
        - The default implementation invokes .flatMap flatMap on this stream,
        passing a function that behaves as follows. First, it calls the mapper function
        with a `DoubleConsumer` that accumulates replacement elements into a newly created
        internal buffer. When the mapper function returns, it creates a `DoubleStream` from the
        internal buffer. Finally, it returns this stream to `flatMap`.
        """
        ...


    def distinct(self) -> "DoubleStream":
        """
        Returns a stream consisting of the distinct elements of this stream. The
        elements are compared for equality according to
        java.lang.Double.compare(double, double).
        
        This is a <a href="package-summary.html#StreamOps">stateful
        intermediate operation</a>.

        Returns
        - the result stream
        """
        ...


    def sorted(self) -> "DoubleStream":
        """
        Returns a stream consisting of the elements of this stream in sorted
        order. The elements are compared for equality according to
        java.lang.Double.compare(double, double).
        
        This is a <a href="package-summary.html#StreamOps">stateful
        intermediate operation</a>.

        Returns
        - the result stream
        """
        ...


    def peek(self, action: "DoubleConsumer") -> "DoubleStream":
        """
        Returns a stream consisting of the elements of this stream, additionally
        performing the provided action on each element as elements are consumed
        from the resulting stream.
        
        This is an <a href="package-summary.html#StreamOps">intermediate
        operation</a>.
        
        For parallel stream pipelines, the action may be called at
        whatever time and in whatever thread the element is made available by the
        upstream operation.  If the action modifies shared state,
        it is responsible for providing the required synchronization.

        Arguments
        - action: a <a href="package-summary.html#NonInterference">
                      non-interfering</a> action to perform on the elements as
                      they are consumed from the stream

        Returns
        - the new stream

        Unknown Tags
        - This method exists mainly to support debugging, where you want
        to see the elements as they flow past a certain point in a pipeline:
        ````DoubleStream.of(1, 2, 3, 4)
                .filter(e -> e > 2)
                .peek(e -> System.out.println("Filtered value: " + e))
                .map(e -> e * e)
                .peek(e -> System.out.println("Mapped value: " + e))
                .sum();````
        
        In cases where the stream implementation is able to optimize away the
        production of some or all the elements (such as with short-circuiting
        operations like `findFirst`, or in the example described in
        .count), the action will not be invoked for those elements.
        """
        ...


    def limit(self, maxSize: int) -> "DoubleStream":
        """
        Returns a stream consisting of the elements of this stream, truncated
        to be no longer than `maxSize` in length.
        
        This is a <a href="package-summary.html#StreamOps">short-circuiting
        stateful intermediate operation</a>.

        Arguments
        - maxSize: the number of elements the stream should be limited to

        Returns
        - the new stream

        Raises
        - IllegalArgumentException: if `maxSize` is negative

        Unknown Tags
        - While `limit()` is generally a cheap operation on sequential
        stream pipelines, it can be quite expensive on ordered parallel pipelines,
        especially for large values of `maxSize`, since `limit(n)`
        is constrained to return not just any *n* elements, but the
        *first n* elements in the encounter order.  Using an unordered
        stream source (such as .generate(DoubleSupplier)) or removing the
        ordering constraint with .unordered() may result in significant
        speedups of `limit()` in parallel pipelines, if the semantics of
        your situation permit.  If consistency with encounter order is required,
        and you are experiencing poor performance or memory utilization with
        `limit()` in parallel pipelines, switching to sequential execution
        with .sequential() may improve performance.
        """
        ...


    def skip(self, n: int) -> "DoubleStream":
        """
        Returns a stream consisting of the remaining elements of this stream
        after discarding the first `n` elements of the stream.
        If this stream contains fewer than `n` elements then an
        empty stream will be returned.
        
        This is a <a href="package-summary.html#StreamOps">stateful
        intermediate operation</a>.

        Arguments
        - n: the number of leading elements to skip

        Returns
        - the new stream

        Raises
        - IllegalArgumentException: if `n` is negative

        Unknown Tags
        - While `skip()` is generally a cheap operation on sequential
        stream pipelines, it can be quite expensive on ordered parallel pipelines,
        especially for large values of `n`, since `skip(n)`
        is constrained to skip not just any *n* elements, but the
        *first n* elements in the encounter order.  Using an unordered
        stream source (such as .generate(DoubleSupplier)) or removing the
        ordering constraint with .unordered() may result in significant
        speedups of `skip()` in parallel pipelines, if the semantics of
        your situation permit.  If consistency with encounter order is required,
        and you are experiencing poor performance or memory utilization with
        `skip()` in parallel pipelines, switching to sequential execution
        with .sequential() may improve performance.
        """
        ...


    def takeWhile(self, predicate: "DoublePredicate") -> "DoubleStream":
        """
        Returns, if this stream is ordered, a stream consisting of the longest
        prefix of elements taken from this stream that match the given predicate.
        Otherwise returns, if this stream is unordered, a stream consisting of a
        subset of elements taken from this stream that match the given predicate.
        
        If this stream is ordered then the longest prefix is a contiguous
        sequence of elements of this stream that match the given predicate.  The
        first element of the sequence is the first element of this stream, and
        the element immediately following the last element of the sequence does
        not match the given predicate.
        
        If this stream is unordered, and some (but not all) elements of this
        stream match the given predicate, then the behavior of this operation is
        nondeterministic; it is free to take any subset of matching elements
        (which includes the empty set).
        
        Independent of whether this stream is ordered or unordered if all
        elements of this stream match the given predicate then this operation
        takes all elements (the result is the same as the input), or if no
        elements of the stream match the given predicate then no elements are
        taken (the result is an empty stream).
        
        This is a <a href="package-summary.html#StreamOps">short-circuiting
        stateful intermediate operation</a>.

        Arguments
        - predicate: a <a href="package-summary.html#NonInterference">non-interfering</a>,
                         <a href="package-summary.html#Statelessness">stateless</a>
                         predicate to apply to elements to determine the longest
                         prefix of elements.

        Returns
        - the new stream

        Since
        - 9

        Unknown Tags
        - The default implementation obtains the .spliterator() spliterator
        of this stream, wraps that spliterator so as to support the semantics
        of this operation on traversal, and returns a new stream associated with
        the wrapped spliterator.  The returned stream preserves the execution
        characteristics of this stream (namely parallel or sequential execution
        as per .isParallel()) but the wrapped spliterator may choose to
        not support splitting.  When the returned stream is closed, the close
        handlers for both the returned and this stream are invoked.
        - While `takeWhile()` is generally a cheap operation on sequential
        stream pipelines, it can be quite expensive on ordered parallel
        pipelines, since the operation is constrained to return not just any
        valid prefix, but the longest prefix of elements in the encounter order.
        Using an unordered stream source (such as
        .generate(DoubleSupplier)) or removing the ordering constraint
        with .unordered() may result in significant speedups of
        `takeWhile()` in parallel pipelines, if the semantics of your
        situation permit.  If consistency with encounter order is required, and
        you are experiencing poor performance or memory utilization with
        `takeWhile()` in parallel pipelines, switching to sequential
        execution with .sequential() may improve performance.
        """
        ...


    def dropWhile(self, predicate: "DoublePredicate") -> "DoubleStream":
        """
        Returns, if this stream is ordered, a stream consisting of the remaining
        elements of this stream after dropping the longest prefix of elements
        that match the given predicate.  Otherwise returns, if this stream is
        unordered, a stream consisting of the remaining elements of this stream
        after dropping a subset of elements that match the given predicate.
        
        If this stream is ordered then the longest prefix is a contiguous
        sequence of elements of this stream that match the given predicate.  The
        first element of the sequence is the first element of this stream, and
        the element immediately following the last element of the sequence does
        not match the given predicate.
        
        If this stream is unordered, and some (but not all) elements of this
        stream match the given predicate, then the behavior of this operation is
        nondeterministic; it is free to drop any subset of matching elements
        (which includes the empty set).
        
        Independent of whether this stream is ordered or unordered if all
        elements of this stream match the given predicate then this operation
        drops all elements (the result is an empty stream), or if no elements of
        the stream match the given predicate then no elements are dropped (the
        result is the same as the input).
        
        This is a <a href="package-summary.html#StreamOps">stateful
        intermediate operation</a>.

        Arguments
        - predicate: a <a href="package-summary.html#NonInterference">non-interfering</a>,
                         <a href="package-summary.html#Statelessness">stateless</a>
                         predicate to apply to elements to determine the longest
                         prefix of elements.

        Returns
        - the new stream

        Since
        - 9

        Unknown Tags
        - The default implementation obtains the .spliterator() spliterator
        of this stream, wraps that spliterator so as to support the semantics
        of this operation on traversal, and returns a new stream associated with
        the wrapped spliterator.  The returned stream preserves the execution
        characteristics of this stream (namely parallel or sequential execution
        as per .isParallel()) but the wrapped spliterator may choose to
        not support splitting.  When the returned stream is closed, the close
        handlers for both the returned and this stream are invoked.
        - While `dropWhile()` is generally a cheap operation on sequential
        stream pipelines, it can be quite expensive on ordered parallel
        pipelines, since the operation is constrained to return not just any
        valid prefix, but the longest prefix of elements in the encounter order.
        Using an unordered stream source (such as
        .generate(DoubleSupplier)) or removing the ordering constraint
        with .unordered() may result in significant speedups of
        `dropWhile()` in parallel pipelines, if the semantics of your
        situation permit.  If consistency with encounter order is required, and
        you are experiencing poor performance or memory utilization with
        `dropWhile()` in parallel pipelines, switching to sequential
        execution with .sequential() may improve performance.
        """
        ...


    def forEach(self, action: "DoubleConsumer") -> None:
        """
        Performs an action for each element of this stream.
        
        This is a <a href="package-summary.html#StreamOps">terminal
        operation</a>.
        
        For parallel stream pipelines, this operation does *not*
        guarantee to respect the encounter order of the stream, as doing so
        would sacrifice the benefit of parallelism.  For any given element, the
        action may be performed at whatever time and in whatever thread the
        library chooses.  If the action accesses shared state, it is
        responsible for providing the required synchronization.

        Arguments
        - action: a <a href="package-summary.html#NonInterference">
                      non-interfering</a> action to perform on the elements
        """
        ...


    def forEachOrdered(self, action: "DoubleConsumer") -> None:
        """
        Performs an action for each element of this stream, guaranteeing that
        each element is processed in encounter order for streams that have a
        defined encounter order.
        
        This is a <a href="package-summary.html#StreamOps">terminal
        operation</a>.

        Arguments
        - action: a <a href="package-summary.html#NonInterference">
                      non-interfering</a> action to perform on the elements

        See
        - .forEach(DoubleConsumer)
        """
        ...


    def toArray(self) -> list[float]:
        """
        Returns an array containing the elements of this stream.
        
        This is a <a href="package-summary.html#StreamOps">terminal
        operation</a>.

        Returns
        - an array containing the elements of this stream
        """
        ...


    def reduce(self, identity: float, op: "DoubleBinaryOperator") -> float:
        """
        Performs a <a href="package-summary.html#Reduction">reduction</a> on the
        elements of this stream, using the provided identity value and an
        <a href="package-summary.html#Associativity">associative</a>
        accumulation function, and returns the reduced value.  This is equivalent
        to:
        ````double result = identity;
            for (double element : this stream)
                result = accumulator.applyAsDouble(result, element)
            return result;````
        
        but is not constrained to execute sequentially.
        
        The `identity` value must be an identity for the accumulator
        function. This means that for all `x`,
        `accumulator.apply(identity, x)` is equal to `x`.
        The `accumulator` function must be an
        <a href="package-summary.html#Associativity">associative</a> function.
        
        This is a <a href="package-summary.html#StreamOps">terminal
        operation</a>.

        Arguments
        - identity: the identity value for the accumulating function
        - op: an <a href="package-summary.html#Associativity">associative</a>,
                  <a href="package-summary.html#NonInterference">non-interfering</a>,
                  <a href="package-summary.html#Statelessness">stateless</a>
                  function for combining two values

        Returns
        - the result of the reduction

        See
        - .average()

        Unknown Tags
        - Sum, min, max, and average are all special cases of reduction.
        Summing a stream of numbers can be expressed as:
        
        ````double sum = numbers.reduce(0, (a, b) -> a+b);````
        
        or more compactly:
        
        ````double sum = numbers.reduce(0, Double::sum);````
        
        While this may seem a more roundabout way to perform an aggregation
        compared to simply mutating a running total in a loop, reduction
        operations parallelize more gracefully, without needing additional
        synchronization and with greatly reduced risk of data races.
        """
        ...


    def reduce(self, op: "DoubleBinaryOperator") -> "OptionalDouble":
        """
        Performs a <a href="package-summary.html#Reduction">reduction</a> on the
        elements of this stream, using an
        <a href="package-summary.html#Associativity">associative</a> accumulation
        function, and returns an `OptionalDouble` describing the reduced
        value, if any. This is equivalent to:
        ````boolean foundAny = False;
            double result = null;
            for (double element : this stream) {
                if (!foundAny) {
                    foundAny = True;
                    result = element;`
                else
                    result = accumulator.applyAsDouble(result, element);
            }
            return foundAny ? OptionalDouble.of(result) : OptionalDouble.empty();
        }```
        
        but is not constrained to execute sequentially.
        
        The `accumulator` function must be an
        <a href="package-summary.html#Associativity">associative</a> function.
        
        This is a <a href="package-summary.html#StreamOps">terminal
        operation</a>.

        Arguments
        - op: an <a href="package-summary.html#Associativity">associative</a>,
                  <a href="package-summary.html#NonInterference">non-interfering</a>,
                  <a href="package-summary.html#Statelessness">stateless</a>
                  function for combining two values

        Returns
        - the result of the reduction

        See
        - .reduce(double, DoubleBinaryOperator)
        """
        ...


    def collect(self, supplier: "Supplier"["R"], accumulator: "ObjDoubleConsumer"["R"], combiner: "BiConsumer"["R", "R"]) -> "R":
        """
        Performs a <a href="package-summary.html#MutableReduction">mutable
        reduction</a> operation on the elements of this stream.  A mutable
        reduction is one in which the reduced value is a mutable result container,
        such as an `ArrayList`, and elements are incorporated by updating
        the state of the result rather than by replacing the result.  This
        produces a result equivalent to:
        ````R result = supplier.get();
            for (double element : this stream)
                accumulator.accept(result, element);
            return result;````
        
        Like .reduce(double, DoubleBinaryOperator), `collect`
        operations can be parallelized without requiring additional
        synchronization.
        
        This is a <a href="package-summary.html#StreamOps">terminal
        operation</a>.
        
        Type `<R>`: the type of the mutable result container

        Arguments
        - supplier: a function that creates a new mutable result container.
                        For a parallel execution, this function may be called
                        multiple times and must return a fresh value each time.
        - accumulator: an <a href="package-summary.html#Associativity">associative</a>,
                           <a href="package-summary.html#NonInterference">non-interfering</a>,
                           <a href="package-summary.html#Statelessness">stateless</a>
                           function that must fold an element into a result
                           container.
        - combiner: an <a href="package-summary.html#Associativity">associative</a>,
                           <a href="package-summary.html#NonInterference">non-interfering</a>,
                           <a href="package-summary.html#Statelessness">stateless</a>
                           function that accepts two partial result containers
                           and merges them, which must be compatible with the
                           accumulator function.  The combiner function must fold
                           the elements from the second result container into the
                           first result container.

        Returns
        - the result of the reduction

        See
        - Stream.collect(Supplier, BiConsumer, BiConsumer)
        """
        ...


    def sum(self) -> float:
        """
        Returns the sum of elements in this stream.
        
        Summation is a special case of a <a
        href="package-summary.html#Reduction">reduction</a>. If
        floating-point summation were exact, this method would be
        equivalent to:
        
        ````return reduce(0, Double::sum);````
        
        However, since floating-point summation is not exact, the above
        code is not necessarily equivalent to the summation computation
        done by this method.
        
        The value of a floating-point sum is a function both
        of the input values as well as the order of addition
        operations. The order of addition operations of this method is
        intentionally not defined to allow for implementation
        flexibility to improve the speed and accuracy of the computed
        result.
        
        In particular, this method may be implemented using compensated
        summation or other technique to reduce the error bound in the
        numerical sum compared to a simple summation of `double`
        values.
        
        Because of the unspecified order of operations and the
        possibility of using differing summation schemes, the output of
        this method may vary on the same input elements.
        
        Various conditions can result in a non-finite sum being
        computed. This can occur even if the all the elements
        being summed are finite. If any element is non-finite,
        the sum will be non-finite:
        
        
        
        - If any element is a NaN, then the final sum will be
        NaN.
        
        - If the elements contain one or more infinities, the
        sum will be infinite or NaN.
        
        
        
        - If the elements contain infinities of opposite sign,
        the sum will be NaN.
        
        - If the elements contain infinities of one sign and
        an intermediate sum overflows to an infinity of the opposite
        sign, the sum may be NaN.
        
        
        
        
        
        It is possible for intermediate sums of finite values to
        overflow into opposite-signed infinities; if that occurs, the
        final sum will be NaN even if the elements are all
        finite.
        
        If all the elements are zero, the sign of zero is
        *not* guaranteed to be preserved in the final sum.
        
        This is a <a href="package-summary.html#StreamOps">terminal
        operation</a>.

        Returns
        - the sum of elements in this stream

        Unknown Tags
        - Elements sorted by increasing absolute magnitude tend
        to yield more accurate results.
        """
        ...


    def min(self) -> "OptionalDouble":
        """
        Returns an `OptionalDouble` describing the minimum element of this
        stream, or an empty OptionalDouble if this stream is empty.  The minimum
        element will be `Double.NaN` if any stream element was NaN. Unlike
        the numerical comparison operators, this method considers negative zero
        to be strictly smaller than positive zero. This is a special case of a
        <a href="package-summary.html#Reduction">reduction</a> and is
        equivalent to:
        ````return reduce(Double::min);````
        
        This is a <a href="package-summary.html#StreamOps">terminal
        operation</a>.

        Returns
        - an `OptionalDouble` containing the minimum element of this
        stream, or an empty optional if the stream is empty
        """
        ...


    def max(self) -> "OptionalDouble":
        """
        Returns an `OptionalDouble` describing the maximum element of this
        stream, or an empty OptionalDouble if this stream is empty.  The maximum
        element will be `Double.NaN` if any stream element was NaN. Unlike
        the numerical comparison operators, this method considers negative zero
        to be strictly smaller than positive zero. This is a
        special case of a
        <a href="package-summary.html#Reduction">reduction</a> and is
        equivalent to:
        ````return reduce(Double::max);````
        
        This is a <a href="package-summary.html#StreamOps">terminal
        operation</a>.

        Returns
        - an `OptionalDouble` containing the maximum element of this
        stream, or an empty optional if the stream is empty
        """
        ...


    def count(self) -> int:
        """
        Returns the count of elements in this stream.  This is a special case of
        a <a href="package-summary.html#Reduction">reduction</a> and is
        equivalent to:
        ````return mapToLong(e -> 1L).sum();````
        
        This is a <a href="package-summary.html#StreamOps">terminal operation</a>.

        Returns
        - the count of elements in this stream

        Unknown Tags
        - An implementation may choose to not execute the stream pipeline (either
        sequentially or in parallel) if it is capable of computing the count
        directly from the stream source.  In such cases no source elements will
        be traversed and no intermediate operations will be evaluated.
        Behavioral parameters with side-effects, which are strongly discouraged
        except for harmless cases such as debugging, may be affected.  For
        example, consider the following stream:
        ````DoubleStream s = DoubleStream.of(1, 2, 3, 4);
            long count = s.peek(System.out::println).count();````
        The number of elements covered by the stream source is known and the
        intermediate operation, `peek`, does not inject into or remove
        elements from the stream (as may be the case for `flatMap` or
        `filter` operations).  Thus the count is 4 and there is no need to
        execute the pipeline and, as a side-effect, print out the elements.
        """
        ...


    def average(self) -> "OptionalDouble":
        """
        Returns an `OptionalDouble` describing the arithmetic
        mean of elements of this stream, or an empty optional if this
        stream is empty.
        
        The computed average can vary numerically and have the
        special case behavior as computing the sum; see .sum
        for details.
        
         The average is a special case of a <a
         href="package-summary.html#Reduction">reduction</a>.
        
        This is a <a href="package-summary.html#StreamOps">terminal
        operation</a>.

        Returns
        - an `OptionalDouble` containing the average element of this
        stream, or an empty optional if the stream is empty

        Unknown Tags
        - Elements sorted by increasing absolute magnitude tend
        to yield more accurate results.
        """
        ...


    def summaryStatistics(self) -> "DoubleSummaryStatistics":
        """
        Returns a `DoubleSummaryStatistics` describing various summary data
        about the elements of this stream.  This is a special
        case of a <a href="package-summary.html#Reduction">reduction</a>.
        
        This is a <a href="package-summary.html#StreamOps">terminal
        operation</a>.

        Returns
        - a `DoubleSummaryStatistics` describing various summary data
        about the elements of this stream
        """
        ...


    def anyMatch(self, predicate: "DoublePredicate") -> bool:
        """
        Returns whether any elements of this stream match the provided
        predicate.  May not evaluate the predicate on all elements if not
        necessary for determining the result.  If the stream is empty then
        `False` is returned and the predicate is not evaluated.
        
        This is a <a href="package-summary.html#StreamOps">short-circuiting
        terminal operation</a>.

        Arguments
        - predicate: a <a href="package-summary.html#NonInterference">non-interfering</a>,
                         <a href="package-summary.html#Statelessness">stateless</a>
                         predicate to apply to elements of this stream

        Returns
        - `True` if any elements of the stream match the provided
        predicate, otherwise `False`

        Unknown Tags
        - This method evaluates the *existential quantification* of the
        predicate over the elements of the stream (for some x P(x)).
        """
        ...


    def allMatch(self, predicate: "DoublePredicate") -> bool:
        """
        Returns whether all elements of this stream match the provided predicate.
        May not evaluate the predicate on all elements if not necessary for
        determining the result.  If the stream is empty then `True` is
        returned and the predicate is not evaluated.
        
        This is a <a href="package-summary.html#StreamOps">short-circuiting
        terminal operation</a>.

        Arguments
        - predicate: a <a href="package-summary.html#NonInterference">non-interfering</a>,
                         <a href="package-summary.html#Statelessness">stateless</a>
                         predicate to apply to elements of this stream

        Returns
        - `True` if either all elements of the stream match the
        provided predicate or the stream is empty, otherwise `False`

        Unknown Tags
        - This method evaluates the *universal quantification* of the
        predicate over the elements of the stream (for all x P(x)).  If the
        stream is empty, the quantification is said to be *vacuously
        satisfied* and is always `True` (regardless of P(x)).
        """
        ...


    def noneMatch(self, predicate: "DoublePredicate") -> bool:
        """
        Returns whether no elements of this stream match the provided predicate.
        May not evaluate the predicate on all elements if not necessary for
        determining the result.  If the stream is empty then `True` is
        returned and the predicate is not evaluated.
        
        This is a <a href="package-summary.html#StreamOps">short-circuiting
        terminal operation</a>.

        Arguments
        - predicate: a <a href="package-summary.html#NonInterference">non-interfering</a>,
                         <a href="package-summary.html#Statelessness">stateless</a>
                         predicate to apply to elements of this stream

        Returns
        - `True` if either no elements of the stream match the
        provided predicate or the stream is empty, otherwise `False`

        Unknown Tags
        - This method evaluates the *universal quantification* of the
        negated predicate over the elements of the stream (for all x ~P(x)).  If
        the stream is empty, the quantification is said to be vacuously satisfied
        and is always `True`, regardless of P(x).
        """
        ...


    def findFirst(self) -> "OptionalDouble":
        """
        Returns an OptionalDouble describing the first element of this
        stream, or an empty `OptionalDouble` if the stream is empty.  If
        the stream has no encounter order, then any element may be returned.
        
        This is a <a href="package-summary.html#StreamOps">short-circuiting
        terminal operation</a>.

        Returns
        - an `OptionalDouble` describing the first element of this
        stream, or an empty `OptionalDouble` if the stream is empty
        """
        ...


    def findAny(self) -> "OptionalDouble":
        """
        Returns an OptionalDouble describing some element of the stream,
        or an empty `OptionalDouble` if the stream is empty.
        
        This is a <a href="package-summary.html#StreamOps">short-circuiting
        terminal operation</a>.
        
        The behavior of this operation is explicitly nondeterministic; it is
        free to select any element in the stream.  This is to allow for maximal
        performance in parallel operations; the cost is that multiple invocations
        on the same source may not return the same result.  (If a stable result
        is desired, use .findFirst() instead.)

        Returns
        - an `OptionalDouble` describing some element of this stream,
        or an empty `OptionalDouble` if the stream is empty

        See
        - .findFirst()
        """
        ...


    def boxed(self) -> "Stream"["Double"]:
        """
        Returns a `Stream` consisting of the elements of this stream,
        boxed to `Double`.
        
        This is an <a href="package-summary.html#StreamOps">intermediate
        operation</a>.

        Returns
        - a `Stream` consistent of the elements of this stream,
        each boxed to a `Double`
        """
        ...


    def sequential(self) -> "DoubleStream":
        ...


    def parallel(self) -> "DoubleStream":
        ...


    def iterator(self) -> "PrimitiveIterator.OfDouble":
        ...


    def spliterator(self) -> "Spliterator.OfDouble":
        ...


    @staticmethod
    def builder() -> "Builder":
        """
        Returns a builder for a `DoubleStream`.

        Returns
        - a stream builder
        """
        ...


    @staticmethod
    def empty() -> "DoubleStream":
        """
        Returns an empty sequential `DoubleStream`.

        Returns
        - an empty sequential stream
        """
        ...


    @staticmethod
    def of(t: float) -> "DoubleStream":
        """
        Returns a sequential `DoubleStream` containing a single element.

        Arguments
        - t: the single element

        Returns
        - a singleton sequential stream
        """
        ...


    @staticmethod
    def of(*values: Tuple[float, ...]) -> "DoubleStream":
        """
        Returns a sequential ordered stream whose elements are the specified values.

        Arguments
        - values: the elements of the new stream

        Returns
        - the new stream
        """
        ...


    @staticmethod
    def iterate(seed: float, f: "DoubleUnaryOperator") -> "DoubleStream":
        """
        Returns an infinite sequential ordered `DoubleStream` produced by iterative
        application of a function `f` to an initial element `seed`,
        producing a `Stream` consisting of `seed`, `f(seed)`,
        `f(f(seed))`, etc.
        
        The first element (position `0`) in the `DoubleStream`
        will be the provided `seed`.  For `n > 0`, the element at
        position `n`, will be the result of applying the function `f`
         to the element at position `n - 1`.
        
        The action of applying `f` for one element
        <a href="../concurrent/package-summary.html#MemoryVisibility">*happens-before*</a>
        the action of applying `f` for subsequent elements.  For any given
        element the action may be performed in whatever thread the library
        chooses.

        Arguments
        - seed: the initial element
        - f: a function to be applied to the previous element to produce
                 a new element

        Returns
        - a new sequential `DoubleStream`
        """
        ...


    @staticmethod
    def iterate(seed: float, hasNext: "DoublePredicate", next: "DoubleUnaryOperator") -> "DoubleStream":
        """
        Returns a sequential ordered `DoubleStream` produced by iterative
        application of the given `next` function to an initial element,
        conditioned on satisfying the given `hasNext` predicate.  The
        stream terminates as soon as the `hasNext` predicate returns False.
        
        `DoubleStream.iterate` should produce the same sequence of elements as
        produced by the corresponding for-loop:
        ````for (double index=seed; hasNext.test(index); index = next.applyAsDouble(index)) {
                ...`
        }```
        
        The resulting sequence may be empty if the `hasNext` predicate
        does not hold on the seed value.  Otherwise the first element will be the
        supplied `seed` value, the next element (if present) will be the
        result of applying the `next` function to the `seed` value,
        and so on iteratively until the `hasNext` predicate indicates that
        the stream should terminate.
        
        The action of applying the `hasNext` predicate to an element
        <a href="../concurrent/package-summary.html#MemoryVisibility">*happens-before*</a>
        the action of applying the `next` function to that element.  The
        action of applying the `next` function for one element
        *happens-before* the action of applying the `hasNext`
        predicate for subsequent elements.  For any given element an action may
        be performed in whatever thread the library chooses.

        Arguments
        - seed: the initial element
        - hasNext: a predicate to apply to elements to determine when the
                       stream must terminate.
        - next: a function to be applied to the previous element to produce
                    a new element

        Returns
        - a new sequential `DoubleStream`

        Since
        - 9
        """
        ...


    @staticmethod
    def generate(s: "DoubleSupplier") -> "DoubleStream":
        """
        Returns an infinite sequential unordered stream where each element is
        generated by the provided `DoubleSupplier`.  This is suitable for
        generating constant streams, streams of random elements, etc.

        Arguments
        - s: the `DoubleSupplier` for generated elements

        Returns
        - a new infinite sequential unordered `DoubleStream`
        """
        ...


    @staticmethod
    def concat(a: "DoubleStream", b: "DoubleStream") -> "DoubleStream":
        """
        Creates a lazily concatenated stream whose elements are all the
        elements of the first stream followed by all the elements of the
        second stream.  The resulting stream is ordered if both
        of the input streams are ordered, and parallel if either of the input
        streams is parallel.  When the resulting stream is closed, the close
        handlers for both input streams are invoked.
        
        This method operates on the two input streams and binds each stream
        to its source.  As a result subsequent modifications to an input stream
        source may not be reflected in the concatenated stream result.

        Arguments
        - a: the first stream
        - b: the second stream

        Returns
        - the concatenation of the two input streams

        Unknown Tags
        - Use caution when constructing streams from repeated concatenation.
        Accessing an element of a deeply concatenated stream can result in deep
        call chains, or even `StackOverflowError`.
        - To preserve optimization opportunities this method binds each stream to
        its source and accepts only two streams as parameters.  For example, the
        exact size of the concatenated stream source can be computed if the exact
        size of each input stream source is known.
        To concatenate more streams without binding, or without nested calls to
        this method, try creating a stream of streams and flat-mapping with the
        identity function, for example:
        ````DoubleStream concat = Stream.of(s1, s2, s3, s4).flatMapToDouble(s -> s);````
        """
        ...


    class Builder(DoubleConsumer):
        """
        A mutable builder for a `DoubleStream`.
        
        A stream builder has a lifecycle, which starts in a building
        phase, during which elements can be added, and then transitions to a built
        phase, after which elements may not be added.  The built phase
        begins when the .build() method is called, which creates an
        ordered stream whose elements are the elements that were added to the
        stream builder, in the order they were added.

        See
        - DoubleStream.builder()

        Since
        - 1.8
        """

        def accept(self, t: float) -> None:
            """
            Adds an element to the stream being built.

            Raises
            - IllegalStateException: if the builder has already transitioned
            to the built state
            """
            ...


        def add(self, t: float) -> "Builder":
            """
            Adds an element to the stream being built.

            Arguments
            - t: the element to add

            Returns
            - `this` builder

            Raises
            - IllegalStateException: if the builder has already transitioned
            to the built state

            Unknown Tags
            - The default implementation behaves as if:
            ````accept(t)
                return this;````
            """
            ...


        def build(self) -> "DoubleStream":
            """
            Builds the stream, transitioning this builder to the built state.
            An `IllegalStateException` is thrown if there are further
            attempts to operate on the builder after it has entered the built
            state.

            Returns
            - the built stream

            Raises
            - IllegalStateException: if the builder has already transitioned
            to the built state
            """
            ...



"""
Python module generated from Java source file org.bukkit.damage.DamageScaling

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.damage import *
from org.bukkit.entity import Player
from typing import Any, Callable, Iterable, Tuple


class DamageScaling(Enum):
    """
    A means of damage scaling with respect to the server's difficulty.
    """

    NEVER = 0
    """
    Damage is not scaled.
    """
    WHEN_CAUSED_BY_LIVING_NON_PLAYER = 1
    """
    Damage is scaled only when the
    DamageSource.getCausingEntity() causing entity is not a
    Player.
    """
    ALWAYS = 2
    """
    Damage is always scaled.
    """



from .InvalidConfigurationException import InvalidConfigurationException
from .ConfigurationOptions import ConfigurationOptions
from .MemoryConfiguration import MemoryConfiguration
from .Configuration import Configuration
from .MemoryConfigurationOptions import MemoryConfigurationOptions
from .ConfigurationSection import ConfigurationSection
from .MemorySection import MemorySection
from .SectionPathData import SectionPathData


"""
Python module generated from Java source file org.joml.Vector2i

Java source file obtained from artifact joml version 1.10.8

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import Externalizable
from java.io import IOException
from java.io import ObjectInput
from java.io import ObjectOutput
from java.text import DecimalFormat
from java.text import NumberFormat
from org.joml import *
from typing import Any, Callable, Iterable, Tuple


class Vector2i(Externalizable, Cloneable, Vector2ic):
    """
    Represents a 2D vector with single-precision.

    Author(s)
    - Hans Uhlig
    """

    def __init__(self):
        """
        Create a new Vector2i and initialize its components to zero.
        """
        ...


    def __init__(self, s: int):
        """
        Create a new Vector2i and initialize both of its components with
        the given value.

        Arguments
        - s: the value of both components
        """
        ...


    def __init__(self, x: int, y: int):
        """
        Create a new Vector2i and initialize its components to the given values.

        Arguments
        - x: the x component
        - y: the y component
        """
        ...


    def __init__(self, x: float, y: float, mode: int):
        """
        Create a new Vector2i and initialize its component values and
        round using the given RoundingMode.

        Arguments
        - x: the x component
        - y: the y component
        - mode: the RoundingMode to use
        """
        ...


    def __init__(self, x: float, y: float, mode: int):
        """
        Create a new Vector2i and initialize its component values and
        round using the given RoundingMode.

        Arguments
        - x: the x component
        - y: the y component
        - mode: the RoundingMode to use
        """
        ...


    def __init__(self, v: "Vector2ic"):
        """
        Create a new Vector2i and initialize its components to the one of
        the given vector.

        Arguments
        - v: the Vector2ic to copy the values from
        """
        ...


    def __init__(self, v: "Vector2fc", mode: int):
        """
        Create a new Vector2i and initialize its components to the rounded value of
        the given vector.

        Arguments
        - v: the Vector2fc to round and copy the values from
        - mode: the RoundingMode to use
        """
        ...


    def __init__(self, v: "Vector2dc", mode: int):
        """
        Create a new Vector2i and initialize its components to the rounded value of
        the given vector.

        Arguments
        - v: the Vector2dc to round and copy the values from
        - mode: the RoundingMode to use
        """
        ...


    def __init__(self, xy: list[int]):
        """
        Create a new Vector2i and initialize its two components from the first
        two elements of the given array.

        Arguments
        - xy: the array containing at least three elements
        """
        ...


    def __init__(self, buffer: "ByteBuffer"):
        """
        Create a new Vector2i and read this vector from the supplied
        ByteBuffer at the current buffer
        ByteBuffer.position() position.
        
        This method will not increment the position of the given ByteBuffer.
        
        In order to specify the offset into the ByteBuffer at which the vector is
        read, use .Vector2i(int, ByteBuffer), taking the absolute
        position as parameter.

        Arguments
        - buffer: values will be read in `x, y` order

        See
        - .Vector2i(int, ByteBuffer)
        """
        ...


    def __init__(self, index: int, buffer: "ByteBuffer"):
        """
        Create a new Vector2i and read this vector from the supplied
        ByteBuffer starting at the specified absolute buffer
        position/index.
        
        This method will not increment the position of the given ByteBuffer.

        Arguments
        - index: the absolute position into the ByteBuffer
        - buffer: values will be read in `x, y` order
        """
        ...


    def __init__(self, buffer: "IntBuffer"):
        """
        Create a new Vector2i and read this vector from the supplied
        IntBuffer at the current buffer
        IntBuffer.position() position.
        
        This method will not increment the position of the given IntBuffer.
        
        In order to specify the offset into the IntBuffer at which the vector is
        read, use .Vector2i(int, IntBuffer), taking the absolute position
        as parameter.

        Arguments
        - buffer: values will be read in `x, y` order

        See
        - .Vector2i(int, IntBuffer)
        """
        ...


    def __init__(self, index: int, buffer: "IntBuffer"):
        """
        Create a new Vector2i and read this vector from the supplied
        IntBuffer starting at the specified absolute buffer
        position/index.
        
        This method will not increment the position of the given IntBuffer.

        Arguments
        - index: the absolute position into the IntBuffer
        - buffer: values will be read in `x, y` order
        """
        ...


    def x(self) -> int:
        ...


    def y(self) -> int:
        ...


    def set(self, s: int) -> "Vector2i":
        """
        Set the x and y components to the supplied value.

        Arguments
        - s: scalar value of both components

        Returns
        - this
        """
        ...


    def set(self, x: int, y: int) -> "Vector2i":
        """
        Set the x and y components to the supplied values.

        Arguments
        - x: the x component
        - y: the y component

        Returns
        - this
        """
        ...


    def set(self, v: "Vector2ic") -> "Vector2i":
        """
        Set this vector to the values of v.

        Arguments
        - v: the vector to copy from

        Returns
        - this
        """
        ...


    def set(self, v: "Vector2dc") -> "Vector2i":
        """
        Set this vector to the values of v using RoundingMode.TRUNCATE rounding.
        
        Note that due to the given vector `v` storing the components
        in double-precision, there is the possibility to lose precision.

        Arguments
        - v: the vector to copy from

        Returns
        - this
        """
        ...


    def set(self, v: "Vector2dc", mode: int) -> "Vector2i":
        """
        Set this vector to the values of v using the given RoundingMode.
        
        Note that due to the given vector `v` storing the components
        in double-precision, there is the possibility to lose precision.

        Arguments
        - v: the vector to copy from
        - mode: the RoundingMode to use

        Returns
        - this
        """
        ...


    def set(self, v: "Vector2fc", mode: int) -> "Vector2i":
        """
        Set this vector to the values of v using the given RoundingMode.
        
        Note that due to the given vector `v` storing the components
        in double-precision, there is the possibility to lose precision.

        Arguments
        - v: the vector to copy from
        - mode: the RoundingMode to use

        Returns
        - this
        """
        ...


    def set(self, xy: list[int]) -> "Vector2i":
        """
        Set the two components of this vector to the first two elements of the given array.

        Arguments
        - xy: the array containing at least two elements

        Returns
        - this
        """
        ...


    def set(self, buffer: "ByteBuffer") -> "Vector2i":
        """
        Read this vector from the supplied ByteBuffer at the current
        buffer ByteBuffer.position() position.
        
        This method will not increment the position of the given ByteBuffer.
        
        In order to specify the offset into the ByteBuffer at which the vector is
        read, use .set(int, ByteBuffer), taking the absolute position as
        parameter.

        Arguments
        - buffer: values will be read in `x, y` order

        Returns
        - this

        See
        - .set(int, ByteBuffer)
        """
        ...


    def set(self, index: int, buffer: "ByteBuffer") -> "Vector2i":
        """
        Read this vector from the supplied ByteBuffer starting at the
        specified absolute buffer position/index.
        
        This method will not increment the position of the given ByteBuffer.

        Arguments
        - index: the absolute position into the ByteBuffer
        - buffer: values will be read in `x, y` order

        Returns
        - this
        """
        ...


    def set(self, buffer: "IntBuffer") -> "Vector2i":
        """
        Read this vector from the supplied IntBuffer at the current
        buffer IntBuffer.position() position.
        
        This method will not increment the position of the given IntBuffer.
        
        In order to specify the offset into the IntBuffer at which the vector is
        read, use .set(int, IntBuffer), taking the absolute position as
        parameter.

        Arguments
        - buffer: values will be read in `x, y` order

        Returns
        - this

        See
        - .set(int, IntBuffer)
        """
        ...


    def set(self, index: int, buffer: "IntBuffer") -> "Vector2i":
        """
        Read this vector from the supplied IntBuffer starting at the
        specified absolute buffer position/index.
        
        This method will not increment the position of the given IntBuffer.

        Arguments
        - index: the absolute position into the IntBuffer
        - buffer: values will be read in `x, y` order

        Returns
        - this
        """
        ...


    def setFromAddress(self, address: int) -> "Vector2i":
        """
        Set the values of this vector by reading 2 integer values from off-heap memory,
        starting at the given address.
        
        This method will throw an UnsupportedOperationException when JOML is used with `-Djoml.nounsafe`.
        
        *This method is unsafe as it can result in a crash of the JVM process when the specified address range does not belong to this process.*

        Arguments
        - address: the off-heap memory address to read the vector values from

        Returns
        - this
        """
        ...


    def get(self, component: int) -> int:
        ...


    def setComponent(self, component: int, value: int) -> "Vector2i":
        """
        Set the value of the specified component of this vector.

        Arguments
        - component: the component whose value to set, within `[0..1]`
        - value: the value to set

        Returns
        - this

        Raises
        - IllegalArgumentException: if `component` is not within `[0..1]`
        """
        ...


    def get(self, buffer: "ByteBuffer") -> "ByteBuffer":
        ...


    def get(self, index: int, buffer: "ByteBuffer") -> "ByteBuffer":
        ...


    def get(self, buffer: "IntBuffer") -> "IntBuffer":
        ...


    def get(self, index: int, buffer: "IntBuffer") -> "IntBuffer":
        ...


    def getToAddress(self, address: int) -> "Vector2ic":
        ...


    def sub(self, v: "Vector2ic") -> "Vector2i":
        """
        Subtract the supplied vector from this one and store the result in
        `this`.

        Arguments
        - v: the vector to subtract

        Returns
        - this
        """
        ...


    def sub(self, v: "Vector2ic", dest: "Vector2i") -> "Vector2i":
        ...


    def sub(self, x: int, y: int) -> "Vector2i":
        """
        Decrement the components of this vector by the given values.

        Arguments
        - x: the x component to subtract
        - y: the y component to subtract

        Returns
        - this
        """
        ...


    def sub(self, x: int, y: int, dest: "Vector2i") -> "Vector2i":
        ...


    def lengthSquared(self) -> int:
        ...


    @staticmethod
    def lengthSquared(x: int, y: int) -> int:
        """
        Get the length squared of a 2-dimensional single-precision vector.

        Arguments
        - x: The vector's x component
        - y: The vector's y component

        Returns
        - the length squared of the given vector
        """
        ...


    def length(self) -> float:
        ...


    @staticmethod
    def length(x: int, y: int) -> float:
        """
        Get the length of a 2-dimensional single-precision vector.

        Arguments
        - x: The vector's x component
        - y: The vector's y component

        Returns
        - the length squared of the given vector
        """
        ...


    def distance(self, v: "Vector2ic") -> float:
        ...


    def distance(self, x: int, y: int) -> float:
        ...


    def distanceSquared(self, v: "Vector2ic") -> int:
        ...


    def distanceSquared(self, x: int, y: int) -> int:
        ...


    def gridDistance(self, v: "Vector2ic") -> int:
        ...


    def gridDistance(self, x: int, y: int) -> int:
        ...


    @staticmethod
    def distance(x1: int, y1: int, x2: int, y2: int) -> float:
        """
        Return the distance between `(x1, y1)` and `(x2, y2)`.

        Arguments
        - x1: the x component of the first vector
        - y1: the y component of the first vector
        - x2: the x component of the second vector
        - y2: the y component of the second vector

        Returns
        - the euclidean distance
        """
        ...


    @staticmethod
    def distanceSquared(x1: int, y1: int, x2: int, y2: int) -> int:
        """
        Return the squared distance between `(x1, y1)` and `(x2, y2)`.

        Arguments
        - x1: the x component of the first vector
        - y1: the y component of the first vector
        - x2: the x component of the second vector
        - y2: the y component of the second vector

        Returns
        - the euclidean distance squared
        """
        ...


    def add(self, v: "Vector2ic") -> "Vector2i":
        """
        Add `v` to this vector.

        Arguments
        - v: the vector to add

        Returns
        - this
        """
        ...


    def add(self, v: "Vector2ic", dest: "Vector2i") -> "Vector2i":
        ...


    def add(self, x: int, y: int) -> "Vector2i":
        """
        Increment the components of this vector by the given values.

        Arguments
        - x: the x component to add
        - y: the y component to add

        Returns
        - this
        """
        ...


    def add(self, x: int, y: int, dest: "Vector2i") -> "Vector2i":
        ...


    def mul(self, scalar: int) -> "Vector2i":
        """
        Multiply all components of this vector by the given scalar
        value.

        Arguments
        - scalar: the scalar to multiply this vector by

        Returns
        - this
        """
        ...


    def mul(self, scalar: int, dest: "Vector2i") -> "Vector2i":
        ...


    def mul(self, v: "Vector2ic") -> "Vector2i":
        """
        Add the supplied vector by this one.

        Arguments
        - v: the vector to multiply

        Returns
        - this
        """
        ...


    def mul(self, v: "Vector2ic", dest: "Vector2i") -> "Vector2i":
        ...


    def mul(self, x: int, y: int) -> "Vector2i":
        """
        Multiply the components of this vector by the given values.

        Arguments
        - x: the x component to multiply
        - y: the y component to multiply

        Returns
        - this
        """
        ...


    def mul(self, x: int, y: int, dest: "Vector2i") -> "Vector2i":
        ...


    def div(self, scalar: float) -> "Vector2i":
        """
        Divide all components of this vector by the given scalar value.

        Arguments
        - scalar: the scalar to divide by

        Returns
        - a vector holding the result
        """
        ...


    def div(self, scalar: float, dest: "Vector2i") -> "Vector2i":
        ...


    def div(self, scalar: int) -> "Vector2i":
        """
        Divide all components of this vector by the given scalar value.

        Arguments
        - scalar: the scalar to divide by

        Returns
        - a vector holding the result
        """
        ...


    def div(self, scalar: int, dest: "Vector2i") -> "Vector2i":
        ...


    def zero(self) -> "Vector2i":
        """
        Set all components to zero.

        Returns
        - this
        """
        ...


    def writeExternal(self, out: "ObjectOutput") -> None:
        ...


    def readExternal(self, in: "ObjectInput") -> None:
        ...


    def negate(self) -> "Vector2i":
        """
        Negate this vector.

        Returns
        - this
        """
        ...


    def negate(self, dest: "Vector2i") -> "Vector2i":
        ...


    def min(self, v: "Vector2ic") -> "Vector2i":
        """
        Set the components of this vector to be the component-wise minimum of this and the other vector.

        Arguments
        - v: the other vector

        Returns
        - this
        """
        ...


    def min(self, v: "Vector2ic", dest: "Vector2i") -> "Vector2i":
        ...


    def max(self, v: "Vector2ic") -> "Vector2i":
        """
        Set the components of this vector to be the component-wise maximum of this and the other vector.

        Arguments
        - v: the other vector

        Returns
        - this
        """
        ...


    def max(self, v: "Vector2ic", dest: "Vector2i") -> "Vector2i":
        ...


    def maxComponent(self) -> int:
        ...


    def minComponent(self) -> int:
        ...


    def absolute(self) -> "Vector2i":
        """
        Set `this` vector's components to their respective absolute values.

        Returns
        - this
        """
        ...


    def absolute(self, dest: "Vector2i") -> "Vector2i":
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def equals(self, x: int, y: int) -> bool:
        ...


    def toString(self) -> str:
        """
        Return a string representation of this vector.
        
        This method creates a new DecimalFormat on every invocation with the format string "`0.000E0;-`".

        Returns
        - the string representation
        """
        ...


    def toString(self, formatter: "NumberFormat") -> str:
        """
        Return a string representation of this vector by formatting the vector components with the given NumberFormat.

        Arguments
        - formatter: the NumberFormat used to format the vector components with

        Returns
        - the string representation
        """
        ...


    def clone(self) -> "Object":
        ...



from .YamlRepresenter import YamlRepresenter
from .FileConfigurationOptions import FileConfigurationOptions
from .YamlConstructor import YamlConstructor
from .YamlConfigurationOptions import YamlConfigurationOptions
from .YamlConfiguration import YamlConfiguration
from .FileConfiguration import FileConfiguration


from .PersistentDataContainer import PersistentDataContainer
from .PersistentDataAdapterContext import PersistentDataAdapterContext
from .ListPersistentDataTypeProvider import ListPersistentDataTypeProvider
from .ListPersistentDataType import ListPersistentDataType
from .PersistentDataHolder import PersistentDataHolder
from .PersistentDataType import PersistentDataType


"""
Python module generated from Java source file com.google.gson.internal.sql.SqlTimestampTypeAdapter

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import Gson
from com.google.gson import TypeAdapter
from com.google.gson import TypeAdapterFactory
from com.google.gson.internal.sql import *
from com.google.gson.reflect import TypeToken
from com.google.gson.stream import JsonReader
from com.google.gson.stream import JsonWriter
from java.io import IOException
from java.util import Date
from typing import Any, Callable, Iterable, Tuple


class SqlTimestampTypeAdapter(TypeAdapter):

    def read(self, in: "JsonReader") -> "Timestamp":
        ...


    def write(self, out: "JsonWriter", value: "Timestamp") -> None:
        ...



"""
Python module generated from Java source file com.google.common.graph.MapRetrievalCache

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.graph import *
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class MapRetrievalCache(MapIteratorCache):
    """
    A MapIteratorCache that adds additional caching. In addition to the caching provided by
    MapIteratorCache, this structure caches values for the two most recently retrieved keys.

    Author(s)
    - James Sexton
    """





"""
Python module generated from Java source file java.io.BufferedInputStream

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from jdk.internal.misc import Unsafe
from jdk.internal.util import ArraysSupport
from typing import Any, Callable, Iterable, Tuple


class BufferedInputStream(FilterInputStream):
    """
    A `BufferedInputStream` adds
    functionality to another input stream-namely,
    the ability to buffer the input and to
    support the `mark` and `reset`
    methods. When  the `BufferedInputStream`
    is created, an internal buffer array is
    created. As bytes  from the stream are read
    or skipped, the internal buffer is refilled
    as necessary  from the contained input stream,
    many bytes at a time. The `mark`
    operation  remembers a point in the input
    stream and the `reset` operation
    causes all the  bytes read since the most
    recent `mark` operation to be
    reread before new bytes are  taken from
    the contained input stream.

    Author(s)
    - Arthur van Hoff

    Since
    - 1.0
    """

    def __init__(self, in: "InputStream"):
        """
        Creates a `BufferedInputStream`
        and saves its  argument, the input stream
        `in`, for later use. An internal
        buffer array is created and  stored in `buf`.

        Arguments
        - in: the underlying input stream.
        """
        ...


    def __init__(self, in: "InputStream", size: int):
        """
        Creates a `BufferedInputStream`
        with the specified buffer size,
        and saves its  argument, the input stream
        `in`, for later use.  An internal
        buffer array of length  `size`
        is created and stored in `buf`.

        Arguments
        - in: the underlying input stream.
        - size: the buffer size.

        Raises
        - IllegalArgumentException: if `size <= 0`.
        """
        ...


    def read(self) -> int:
        """
        See
        the general contract of the `read`
        method of `InputStream`.

        Returns
        - the next byte of data, or `-1` if the end of the
                    stream is reached.

        Raises
        - IOException: if this input stream has been closed by
                                 invoking its .close() method,
                                 or an I/O error occurs.

        See
        - java.io.FilterInputStream.in
        """
        ...


    def read(self, b: list[int], off: int, len: int) -> int:
        """
        Reads bytes from this byte-input stream into the specified byte array,
        starting at the given offset.
        
         This method implements the general contract of the corresponding
        InputStream.read(byte[], int, int) read method of
        the InputStream class.  As an additional
        convenience, it attempts to read as many bytes as possible by repeatedly
        invoking the `read` method of the underlying stream.  This
        iterated `read` continues until one of the following
        conditions becomes True: 
        
          -  The specified number of bytes have been read,
        
          -  The `read` method of the underlying stream returns
          `-1`, indicating end-of-file, or
        
          -  The `available` method of the underlying stream
          returns zero, indicating that further input requests would block.
        
         If the first `read` on the underlying stream returns
        `-1` to indicate end-of-file then this method returns
        `-1`.  Otherwise this method returns the number of bytes
        actually read.
        
         Subclasses of this class are encouraged, but not required, to
        attempt to read as many bytes as possible in the same fashion.

        Arguments
        - b: destination buffer.
        - off: offset at which to start storing bytes.
        - len: maximum number of bytes to read.

        Returns
        - the number of bytes read, or `-1` if the end of
                    the stream has been reached.

        Raises
        - IOException: if this input stream has been closed by
                                 invoking its .close() method,
                                 or an I/O error occurs.
        """
        ...


    def skip(self, n: int) -> int:
        """
        See the general contract of the `skip`
        method of `InputStream`.

        Raises
        - IOException: if this input stream has been closed by
                             invoking its .close() method,
                             `in.skip(n)` throws an IOException,
                             or an I/O error occurs.
        """
        ...


    def available(self) -> int:
        """
        Returns an estimate of the number of bytes that can be read (or
        skipped over) from this input stream without blocking by the next
        invocation of a method for this input stream. The next invocation might be
        the same thread or another thread.  A single read or skip of this
        many bytes will not block, but may read or skip fewer bytes.
        
        This method returns the sum of the number of bytes remaining to be read in
        the buffer (`count - pos`) and the result of calling the
        java.io.FilterInputStream.in in`.available()`.

        Returns
        - an estimate of the number of bytes that can be read (or skipped
                    over) from this input stream without blocking.

        Raises
        - IOException: if this input stream has been closed by
                                 invoking its .close() method,
                                 or an I/O error occurs.
        """
        ...


    def mark(self, readlimit: int) -> None:
        """
        See the general contract of the `mark`
        method of `InputStream`.

        Arguments
        - readlimit: the maximum limit of bytes that can be read before
                             the mark position becomes invalid.

        See
        - java.io.BufferedInputStream.reset()
        """
        ...


    def reset(self) -> None:
        """
        See the general contract of the `reset`
        method of `InputStream`.
        
        If `markpos` is `-1`
        (no mark has been set or the mark has been
        invalidated), an `IOException`
        is thrown. Otherwise, `pos` is
        set equal to `markpos`.

        Raises
        - IOException: if this stream has not been marked or,
                         if the mark has been invalidated, or the stream
                         has been closed by invoking its .close()
                         method, or an I/O error occurs.

        See
        - java.io.BufferedInputStream.mark(int)
        """
        ...


    def markSupported(self) -> bool:
        """
        Tests if this input stream supports the `mark`
        and `reset` methods. The `markSupported`
        method of `BufferedInputStream` returns
        `True`.

        Returns
        - a `boolean` indicating if this stream type supports
                 the `mark` and `reset` methods.

        See
        - java.io.InputStream.reset()
        """
        ...


    def close(self) -> None:
        """
        Closes this input stream and releases any system resources
        associated with the stream.
        Once the stream has been closed, further read(), available(), reset(),
        or skip() invocations will throw an IOException.
        Closing a previously closed stream has no effect.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...



"""
Python module generated from Java source file org.bukkit.plugin.RegisteredListener

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.event import Cancellable
from org.bukkit.event import Event
from org.bukkit.event import EventException
from org.bukkit.event import EventPriority
from org.bukkit.event import Listener
from org.bukkit.plugin import *
from typing import Any, Callable, Iterable, Tuple


class RegisteredListener:
    """
    Stores relevant information for plugin listeners
    """

    def __init__(self, listener: "Listener", executor: "EventExecutor", priority: "EventPriority", plugin: "Plugin", ignoreCancelled: bool):
        ...


    def getListener(self) -> "Listener":
        """
        Gets the listener for this registration

        Returns
        - Registered Listener
        """
        ...


    def getPlugin(self) -> "Plugin":
        """
        Gets the plugin for this registration

        Returns
        - Registered Plugin
        """
        ...


    def getPriority(self) -> "EventPriority":
        """
        Gets the priority for this registration

        Returns
        - Registered Priority
        """
        ...


    def callEvent(self, event: "Event") -> None:
        """
        Calls the event executor

        Arguments
        - event: The event

        Raises
        - EventException: If an event handler throws an exception.
        """
        ...


    def isIgnoringCancelled(self) -> bool:
        """
        Whether this listener accepts cancelled events

        Returns
        - True when ignoring cancelled events
        """
        ...
